@@ -4,14 +4,12 @@ pub mod filtered_lines;
 pub mod fix_coordinator;
 pub mod inline_config;
 pub mod lint_context;
-pub mod lsp;
 pub mod markdownlint_config;
-pub mod output;
-pub mod parallel;
-pub mod performance;
 pub mod profiling;
 pub mod rule;
+#[cfg(feature = "native")]
 pub mod vscode;
+pub mod workspace_index;
 #[macro_use]
 pub mod rule_config;
 #[macro_use]
@@ -20,11 +18,27 @@ pub mod rules;
 pub mod types;
 pub mod utils;
 
+// Native-only modules (require tokio, tower-lsp, etc.)
+#[cfg(feature = "native")]
+pub mod lsp;
+#[cfg(feature = "native")]
+pub mod output;
+#[cfg(feature = "native")]
+pub mod parallel;
+#[cfg(feature = "native")]
+pub mod performance;
+
+// WASM module
+#[cfg(all(target_arch = "wasm32", feature = "wasm"))]
+pub mod wasm;
+
 pub use rules::heading_utils::{Heading, HeadingStyle};
 pub use rules::*;
 
 pub use crate::lint_context::{LineInfo, LintContext, ListItemInfo};
 use crate::rule::{LintResult, Rule, RuleCategory};
+use crate::utils::element_cache::ElementCache;
+#[cfg(not(target_arch = "wasm32"))]
 use std::time::Instant;
 
 /// Content characteristics for efficient rule filtering
@@ -41,6 +55,12 @@ struct ContentCharacteristics {
     has_images: bool,      // ![alt](url)
 }
 
+/// Check if a line has enough leading whitespace to be an indented code block.
+/// Indented code blocks require 4+ columns of leading whitespace (with proper tab expansion).
+fn has_potential_indented_code_indent(line: &str) -> bool {
+    ElementCache::calculate_indentation_width_default(line) >= 4
+}
+
 impl ContentCharacteristics {
     fn analyze(content: &str) -> Self {
         let mut chars = Self { ..Default::default() };
@@ -61,24 +81,41 @@ impl ContentCharacteristics {
             }
 
             // Quick character-based detection (more efficient than regex)
-            if !chars.has_lists && (line.contains("* ") || line.contains("- ") || line.contains("+ ")) {
+            // Include patterns without spaces to enable user-intention detection (MD030)
+            if !chars.has_lists
+                && (line.contains("* ")
+                    || line.contains("- ")
+                    || line.contains("+ ")
+                    || trimmed.starts_with("* ")
+                    || trimmed.starts_with("- ")
+                    || trimmed.starts_with("+ ")
+                    || trimmed.starts_with('*')
+                    || trimmed.starts_with('-')
+                    || trimmed.starts_with('+'))
+            {
                 chars.has_lists = true;
             }
-            if !chars.has_lists && line.chars().next().is_some_and(|c| c.is_ascii_digit()) && line.contains(". ") {
+            if !chars.has_lists
+                && line.chars().next().is_some_and(|c| c.is_ascii_digit())
+                && (line.contains(". ") || line.contains('.'))
+            {
                 chars.has_lists = true;
             }
             if !chars.has_links
                 && (line.contains('[')
                     || line.contains("http://")
                     || line.contains("https://")
-                    || line.contains("ftp://"))
+                    || line.contains("ftp://")
+                    || line.contains("www."))
             {
                 chars.has_links = true;
             }
             if !chars.has_images && line.contains("![") {
                 chars.has_images = true;
             }
-            if !chars.has_code && (line.contains('`') || line.contains("~~~")) {
+            if !chars.has_code
+                && (line.contains('`') || line.contains("~~~") || has_potential_indented_code_indent(line))
+            {
                 chars.has_code = true;
             }
             if !chars.has_emphasis && (line.contains('*') || line.contains('_')) {
@@ -117,26 +154,109 @@ impl ContentCharacteristics {
     }
 }
 
+/// Compute content hash for incremental indexing change detection
+///
+/// Uses blake3 for native builds (fast, cryptographic-strength hash)
+/// Falls back to std::hash for WASM builds
+#[cfg(feature = "native")]
+fn compute_content_hash(content: &str) -> String {
+    blake3::hash(content.as_bytes()).to_hex().to_string()
+}
+
+/// Compute content hash for WASM builds using std::hash
+#[cfg(not(feature = "native"))]
+fn compute_content_hash(content: &str) -> String {
+    use std::hash::{DefaultHasher, Hash, Hasher};
+    let mut hasher = DefaultHasher::new();
+    content.hash(&mut hasher);
+    format!("{:016x}", hasher.finish())
+}
+
 /// Lint a file against the given rules with intelligent rule filtering
 /// Assumes the provided `rules` vector contains the final,
 /// configured, and filtered set of rules to be executed.
 pub fn lint(
+    content: &str,
+    rules: &[Box<dyn Rule>],
+    verbose: bool,
+    flavor: crate::config::MarkdownFlavor,
+    config: Option<&crate::config::Config>,
+) -> LintResult {
+    // Use lint_and_index but discard the FileIndex for backward compatibility
+    let (result, _file_index) = lint_and_index(content, rules, verbose, flavor, None, config);
+    result
+}
+
+/// Build FileIndex only (no linting) for cross-file analysis on cache hits
+///
+/// This is a lightweight function that only builds the FileIndex without running
+/// any rules. Used when we have a cache hit but still need the FileIndex for
+/// cross-file validation.
+///
+/// This avoids the overhead of re-running all rules when only the index data is needed.
+pub fn build_file_index_only(
+    content: &str,
+    rules: &[Box<dyn Rule>],
+    flavor: crate::config::MarkdownFlavor,
+) -> crate::workspace_index::FileIndex {
+    // Compute content hash for change detection
+    let content_hash = compute_content_hash(content);
+    let mut file_index = crate::workspace_index::FileIndex::with_hash(content_hash);
+
+    // Early return for empty content
+    if content.is_empty() {
+        return file_index;
+    }
+
+    // Parse LintContext once with the provided flavor
+    let lint_ctx = crate::lint_context::LintContext::new(content, flavor, None);
+
+    // Only call contribute_to_index for cross-file rules (no rule checking!)
+    for rule in rules {
+        if rule.cross_file_scope() == crate::rule::CrossFileScope::Workspace {
+            rule.contribute_to_index(&lint_ctx, &mut file_index);
+        }
+    }
+
+    file_index
+}
+
+/// Lint a file and contribute to workspace index for cross-file analysis
+///
+/// This variant performs linting and optionally populates a `FileIndex` with data
+/// needed for cross-file validation. The FileIndex is populated during linting,
+/// avoiding duplicate parsing.
+///
+/// Returns: (warnings, FileIndex) - the FileIndex contains headings/links for cross-file rules
+pub fn lint_and_index(
     content: &str,
     rules: &[Box<dyn Rule>],
     _verbose: bool,
     flavor: crate::config::MarkdownFlavor,
-) -> LintResult {
+    source_file: Option<std::path::PathBuf>,
+    config: Option<&crate::config::Config>,
+) -> (LintResult, crate::workspace_index::FileIndex) {
     let mut warnings = Vec::new();
+    // Compute content hash for change detection
+    let content_hash = compute_content_hash(content);
+    let mut file_index = crate::workspace_index::FileIndex::with_hash(content_hash);
+
+    #[cfg(not(target_arch = "wasm32"))]
     let _overall_start = Instant::now();
 
     // Early return for empty content
     if content.is_empty() {
-        return Ok(warnings);
+        return (Ok(warnings), file_index);
     }
 
     // Parse inline configuration comments once
     let inline_config = crate::inline_config::InlineConfig::from_content(content);
 
+    // Export inline config data to FileIndex for cross-file rule filtering
+    let (file_disabled, line_disabled) = inline_config.export_for_file_index();
+    file_index.file_disabled_rules = file_disabled;
+    file_index.line_disabled_rules = line_disabled;
+
     // Analyze content characteristics for rule filtering
     let characteristics = ContentCharacteristics::analyze(content);
 
@@ -151,13 +271,18 @@ pub fn lint(
     let _applicable_count = applicable_rules.len();
 
     // Parse LintContext once with the provided flavor
-    let lint_ctx = crate::lint_context::LintContext::new(content, flavor);
+    let lint_ctx = crate::lint_context::LintContext::new(content, flavor, source_file);
 
+    #[cfg(not(target_arch = "wasm32"))]
     let profile_rules = std::env::var("RUMDL_PROFILE_RULES").is_ok();
+    #[cfg(target_arch = "wasm32")]
+    let profile_rules = false;
 
-    for rule in applicable_rules {
+    for rule in &applicable_rules {
+        #[cfg(not(target_arch = "wasm32"))]
         let _rule_start = Instant::now();
 
+        // Run single-file check
         let result = rule.check(&lint_ctx);
 
         match result {
@@ -181,23 +306,48 @@ pub fn lint(
                             warning.line, // Already 1-indexed
                         )
                     })
+                    .map(|mut warning| {
+                        // Apply severity override from config if present
+                        if let Some(cfg) = config {
+                            let rule_name_to_check = warning.rule_name.as_deref().unwrap_or(rule.name());
+                            if let Some(override_severity) = cfg.get_rule_severity(rule_name_to_check) {
+                                warning.severity = override_severity;
+                            }
+                        }
+                        warning
+                    })
                     .collect();
                 warnings.extend(filtered_warnings);
             }
             Err(e) => {
                 log::error!("Error checking rule {}: {}", rule.name(), e);
-                return Err(e);
+                return (Err(e), file_index);
             }
         }
 
-        let rule_duration = _rule_start.elapsed();
-        if profile_rules {
-            eprintln!("[RULE] {:6} {:?}", rule.name(), rule_duration);
-        }
+        #[cfg(not(target_arch = "wasm32"))]
+        {
+            let rule_duration = _rule_start.elapsed();
+            if profile_rules {
+                eprintln!("[RULE] {:6} {:?}", rule.name(), rule_duration);
+            }
 
-        #[cfg(not(test))]
-        if _verbose && rule_duration.as_millis() > 500 {
-            log::debug!("Rule {} took {:?}", rule.name(), rule_duration);
+            #[cfg(not(test))]
+            if _verbose && rule_duration.as_millis() > 500 {
+                log::debug!("Rule {} took {:?}", rule.name(), rule_duration);
+            }
+        }
+    }
+
+    // Contribute to index for cross-file rules (done after all rules checked)
+    // NOTE: We iterate over ALL rules (not just applicable_rules) because cross-file
+    // rules need to extract data from every file in the workspace, regardless of whether
+    // that file has content that would trigger the rule. For example, MD051 needs to
+    // index headings from files that have no links (like target.md) so that links
+    // FROM other files TO those headings can be validated.
+    for rule in rules {
+        if rule.cross_file_scope() == crate::rule::CrossFileScope::Workspace {
+            rule.contribute_to_index(&lint_ctx, &mut file_index);
         }
     }
 
@@ -209,6 +359,63 @@ pub fn lint(
         }
     }
 
+    (Ok(warnings), file_index)
+}
+
+/// Run cross-file checks for rules that need workspace-wide validation
+///
+/// This should be called after all files have been linted and the WorkspaceIndex
+/// has been built from the accumulated FileIndex data.
+///
+/// Note: This takes the FileIndex instead of content to avoid re-parsing each file.
+/// The FileIndex was already populated during contribute_to_index in the linting phase.
+///
+/// Rules can use workspace_index methods for cross-file validation:
+/// - `get_file(path)` - to look up headings in target files (for MD051)
+///
+/// Returns additional warnings from cross-file validation.
+pub fn run_cross_file_checks(
+    file_path: &std::path::Path,
+    file_index: &crate::workspace_index::FileIndex,
+    rules: &[Box<dyn Rule>],
+    workspace_index: &crate::workspace_index::WorkspaceIndex,
+    config: Option<&crate::config::Config>,
+) -> LintResult {
+    use crate::rule::CrossFileScope;
+
+    let mut warnings = Vec::new();
+
+    // Only check rules that need cross-file analysis
+    for rule in rules {
+        if rule.cross_file_scope() != CrossFileScope::Workspace {
+            continue;
+        }
+
+        match rule.cross_file_check(file_path, file_index, workspace_index) {
+            Ok(rule_warnings) => {
+                // Filter cross-file warnings based on inline config stored in file_index
+                let filtered: Vec<_> = rule_warnings
+                    .into_iter()
+                    .filter(|w| !file_index.is_rule_disabled_at_line(rule.name(), w.line))
+                    .map(|mut warning| {
+                        // Apply severity override from config if present
+                        if let Some(cfg) = config
+                            && let Some(override_severity) = cfg.get_rule_severity(rule.name())
+                        {
+                            warning.severity = override_severity;
+                        }
+                        warning
+                    })
+                    .collect();
+                warnings.extend(filtered);
+            }
+            Err(e) => {
+                log::error!("Error in cross-file check for rule {}: {}", rule.name(), e);
+                return Err(e);
+            }
+        }
+    }
+
     Ok(warnings)
 }
 
@@ -282,6 +489,22 @@ mod tests {
         let chars = ContentCharacteristics::analyze("~~~\ncode block\n~~~");
         assert!(chars.has_code);
 
+        // Test indented code blocks (4 spaces)
+        let chars = ContentCharacteristics::analyze("Text\n\n    indented code\n\nMore text");
+        assert!(chars.has_code);
+
+        // Test tab-indented code blocks
+        let chars = ContentCharacteristics::analyze("Text\n\n\ttab indented code\n\nMore text");
+        assert!(chars.has_code);
+
+        // Test mixed whitespace indented code (2 spaces + tab = 4 columns)
+        let chars = ContentCharacteristics::analyze("Text\n\n  \tmixed indent code\n\nMore text");
+        assert!(chars.has_code);
+
+        // Test 1 space + tab (also 4 columns due to tab expansion)
+        let chars = ContentCharacteristics::analyze("Text\n\n \ttab after space\n\nMore text");
+        assert!(chars.has_code);
+
         // Test emphasis
         let chars = ContentCharacteristics::analyze("*emphasis* and _more_");
         assert!(chars.has_emphasis);
@@ -327,7 +550,7 @@ mod tests {
         };
 
         // Create test rules for different categories
-        let heading_rule = MD001HeadingIncrement;
+        let heading_rule = MD001HeadingIncrement::default();
         assert!(!chars.should_skip_rule(&heading_rule));
 
         let trailing_spaces_rule = MD009TrailingSpaces::new(2, false);
@@ -343,9 +566,9 @@ mod tests {
 
     #[test]
     fn test_lint_empty_content() {
-        let rules: Vec<Box<dyn Rule>> = vec![Box::new(MD001HeadingIncrement)];
+        let rules: Vec<Box<dyn Rule>> = vec![Box::new(MD001HeadingIncrement::default())];
 
-        let result = lint("", &rules, false, crate::config::MarkdownFlavor::Standard);
+        let result = lint("", &rules, false, crate::config::MarkdownFlavor::Standard, None);
         assert!(result.is_ok());
         assert!(result.unwrap().is_empty());
     }
@@ -353,9 +576,9 @@ mod tests {
     #[test]
     fn test_lint_with_violations() {
         let content = "## Level 2\n#### Level 4"; // Skips level 3
-        let rules: Vec<Box<dyn Rule>> = vec![Box::new(MD001HeadingIncrement)];
+        let rules: Vec<Box<dyn Rule>> = vec![Box::new(MD001HeadingIncrement::default())];
 
-        let result = lint(content, &rules, false, crate::config::MarkdownFlavor::Standard);
+        let result = lint(content, &rules, false, crate::config::MarkdownFlavor::Standard, None);
         assert!(result.is_ok());
         let warnings = result.unwrap();
         assert!(!warnings.is_empty());
@@ -366,9 +589,9 @@ mod tests {
     #[test]
     fn test_lint_with_inline_disable() {
         let content = "<!-- rumdl-disable MD001 -->\n## Level 2\n#### Level 4";
-        let rules: Vec<Box<dyn Rule>> = vec![Box::new(MD001HeadingIncrement)];
+        let rules: Vec<Box<dyn Rule>> = vec![Box::new(MD001HeadingIncrement::default())];
 
-        let result = lint(content, &rules, false, crate::config::MarkdownFlavor::Standard);
+        let result = lint(content, &rules, false, crate::config::MarkdownFlavor::Standard, None);
         assert!(result.is_ok());
         let warnings = result.unwrap();
         assert!(warnings.is_empty()); // Should be disabled by inline comment
@@ -379,11 +602,11 @@ mod tests {
         // Content with no lists
         let content = "# Heading\nJust text";
         let rules: Vec<Box<dyn Rule>> = vec![
-            Box::new(MD001HeadingIncrement),
+            Box::new(MD001HeadingIncrement::default()),
             // A list-related rule would be skipped
         ];
 
-        let result = lint(content, &rules, false, crate::config::MarkdownFlavor::Standard);
+        let result = lint(content, &rules, false, crate::config::MarkdownFlavor::Standard, None);
         assert!(result.is_ok());
     }
 
@@ -426,12 +649,13 @@ mod tests {
         let chars = ContentCharacteristics::analyze("--"); // Two dashes, valid setext
         assert!(chars.has_headings);
 
-        // Test list detection edge cases
-        let chars = ContentCharacteristics::analyze("*emphasis*"); // Not a list
-        assert!(!chars.has_lists);
+        // Test list detection - we now include potential list patterns (with or without space)
+        // to support user-intention detection in MD030
+        let chars = ContentCharacteristics::analyze("*emphasis*"); // Could be list or emphasis
+        assert!(chars.has_lists); // Run list rules to be safe
 
-        let chars = ContentCharacteristics::analyze("1.Item"); // No space after period
-        assert!(!chars.has_lists);
+        let chars = ContentCharacteristics::analyze("1.Item"); // Could be list without space
+        assert!(chars.has_lists); // Run list rules for user-intention detection
 
         // Test blockquote must be at start of line
         let chars = ContentCharacteristics::analyze("text > not a quote");
