@@ -901,6 +901,13 @@ fn main() -> Result<(), Box<dyn Error>> {
         }
     }
 
+    // Initialize logging from RUST_LOG environment variable
+    // This allows users to debug config discovery with: RUST_LOG=debug rumdl check ...
+    env_logger::Builder::from_default_env()
+        .format_timestamp(None)
+        .format_target(false)
+        .init();
+
     let cli = Cli::parse();
 
     // Set color override globally based on --color flag
@@ -938,6 +945,7 @@ fn main() -> Result<(), Box<dyn Error>> {
                                         println!(
                                             "Please edit the file manually to avoid overwriting existing configuration."
                                         );
+                                        return;
                                     }
 
                                     // Append with a blank line for separation
@@ -1030,71 +1038,9 @@ build-backend = "setuptools.build_meta"
                 }
             }
             Commands::Rule { rule } => {
-                use rumdl_lib::rules::*;
-                let all_rules: Vec<Box<dyn Rule>> = vec![
-                    Box::new(MD001HeadingIncrement::default()),
-                    Box::new(MD003HeadingStyle::default()),
-                    Box::new(MD004UnorderedListStyle::new(UnorderedListStyle::Consistent)),
-                    Box::new(MD005ListIndent::default()),
-                    Box::new(MD007ULIndent::default()),
-                    Box::new(MD009TrailingSpaces::default()),
-                    Box::new(MD010NoHardTabs::default()),
-                    Box::new(MD011NoReversedLinks {}),
-                    Box::new(MD012NoMultipleBlanks::default()),
-                    Box::new(MD013LineLength::default()),
-                    Box::new(MD014CommandsShowOutput::default()),
-                    Box::new(MD018NoMissingSpaceAtx {}),
-                    Box::new(MD019NoMultipleSpaceAtx {}),
-                    Box::new(MD020NoMissingSpaceClosedAtx {}),
-                    Box::new(MD021NoMultipleSpaceClosedAtx {}),
-                    Box::new(MD022BlanksAroundHeadings::default()),
-                    Box::new(MD023HeadingStartLeft {}),
-                    Box::new(MD024NoDuplicateHeading::default()),
-                    Box::new(MD025SingleTitle::default()),
-                    Box::new(MD026NoTrailingPunctuation::default()),
-                    Box::new(MD027MultipleSpacesBlockquote {}),
-                    Box::new(MD028NoBlanksBlockquote {}),
-                    Box::new(MD029OrderedListPrefix::default()),
-                    Box::new(MD030ListMarkerSpace::default()),
-                    Box::new(MD031BlanksAroundFences::default()),
-                    Box::new(MD032BlanksAroundLists::default()),
-                    Box::new(MD033NoInlineHtml::default()),
-                    Box::new(MD034NoBareUrls {}),
-                    Box::new(MD035HRStyle::default()),
-                    Box::new(MD036NoEmphasisAsHeading::new(".,;:!?".to_string())),
-                    Box::new(MD037NoSpaceInEmphasis),
-                    Box::new(MD038NoSpaceInCode::default()),
-                    Box::new(MD039NoSpaceInLinks),
-                    Box::new(MD040FencedCodeLanguage {}),
-                    Box::new(MD041FirstLineHeading::default()),
-                    Box::new(MD042NoEmptyLinks::new()),
-                    Box::new(MD043RequiredHeadings::new(Vec::new())),
-                    Box::new(MD044ProperNames::new(Vec::new(), true)),
-                    Box::new(MD045NoAltText::new()),
-                    Box::new(MD046CodeBlockStyle::new(CodeBlockStyle::Consistent)),
-                    Box::new(MD047SingleTrailingNewline),
-                    Box::new(MD048CodeFenceStyle::new(CodeFenceStyle::Consistent)),
-                    Box::new(MD049EmphasisStyle::default()),
-                    Box::new(MD050StrongStyle::new(StrongStyle::Consistent)),
-                    Box::new(MD051LinkFragments::new()),
-                    Box::new(MD052ReferenceLinkImages::new()),
-                    Box::new(MD053LinkImageReferenceDefinitions::default()),
-                    Box::new(MD054LinkImageStyle::default()),
-                    Box::new(MD055TablePipeStyle::default()),
-                    Box::new(MD056TableColumnCount),
-                    Box::new(MD057ExistingRelativeLinks::default()),
-                    Box::new(MD058BlanksAroundTables::default()),
-                    Box::new(MD059LinkText::default()),
-                    Box::new(MD060TableFormat::default()),
-                    Box::new(MD061ForbiddenTerms::default()),
-                    Box::new(MD062LinkDestinationWhitespace::new()),
-                    Box::new(MD063HeadingCapitalization::default()),
-                    Box::new(MD064NoMultipleConsecutiveSpaces::new()),
-                    Box::new(MD065BlanksAroundHorizontalRules),
-                    Box::new(MD066FootnoteValidation),
-                    Box::new(MD067FootnoteDefinitionOrder),
-                    Box::new(MD068EmptyFootnoteDefinition),
-                ];
+                // Use the canonical all_rules function to avoid drift between CLI and library
+                let default_config = rumdl_lib::config::Config::default();
+                let all_rules = rumdl_lib::rules::all_rules(&default_config);
                 if let Some(rule_query) = rule {
                     let rule_query = rule_query.to_ascii_uppercase();
                     let found = all_rules.iter().find(|r| {
@@ -1481,15 +1427,10 @@ build-backend = "setuptools.build_meta"
                 verbose,
                 config,
             } => {
-                // Setup logging for the LSP server
+                // If verbose flag is set, increase log level to Debug
+                // (logging is already initialized in main() via RUST_LOG)
                 if verbose {
-                    env_logger::Builder::from_default_env()
-                        .filter_level(log::LevelFilter::Debug)
-                        .init();
-                } else {
-                    env_logger::Builder::from_default_env()
-                        .filter_level(log::LevelFilter::Info)
-                        .init();
+                    log::set_max_level(log::LevelFilter::Debug);
                 }
 
                 // Validate config file exists if provided
