@@ -9,7 +9,7 @@ use std::fs;
 
 /// Represents a generic markdownlint config (rule keys to values)
 #[derive(Debug, Deserialize)]
-pub struct MarkdownlintConfig(pub HashMap<String, serde_yaml::Value>);
+pub struct MarkdownlintConfig(pub HashMap<String, serde_yml::Value>);
 
 /// Load a markdownlint config file (JSON or YAML) from the given path
 pub fn load_markdownlint_config(path: &str) -> Result<MarkdownlintConfig, String> {
@@ -18,75 +18,20 @@ pub fn load_markdownlint_config(path: &str) -> Result<MarkdownlintConfig, String
     if path.ends_with(".json") || path.ends_with(".jsonc") {
         serde_json::from_str(&content).map_err(|e| format!("Failed to parse JSON: {e}"))
     } else if path.ends_with(".yaml") || path.ends_with(".yml") {
-        serde_yaml::from_str(&content).map_err(|e| format!("Failed to parse YAML: {e}"))
+        serde_yml::from_str(&content).map_err(|e| format!("Failed to parse YAML: {e}"))
     } else {
         serde_json::from_str(&content)
-            .or_else(|_| serde_yaml::from_str(&content))
+            .or_else(|_| serde_yml::from_str(&content))
             .map_err(|e| format!("Failed to parse config as JSON or YAML: {e}"))
     }
 }
 
 /// Mapping table from markdownlint rule keys/aliases to rumdl rule keys
-fn markdownlint_to_rumdl_rule_key(key: &str) -> Option<&'static str> {
-    // Convert key to uppercase and replace underscores with hyphens for normalization
-    let normalized_key = key.to_ascii_uppercase().replace('_', "-");
-    match normalized_key.as_str() {
-        "MD001" | "HEADING-INCREMENT" => Some("MD001"),
-        "MD003" | "HEADING-STYLE" => Some("MD003"),
-        "MD004" | "UL-STYLE" => Some("MD004"),
-        "MD005" | "LIST-INDENT" => Some("MD005"),
-        "MD007" | "UL-INDENT" => Some("MD007"),
-        "MD008" => Some("MD008"),
-        "MD009" | "NO-TRAILING-SPACES" => Some("MD009"),
-        "MD010" | "NO-HARD-TABS" => Some("MD010"),
-        "MD011" | "NO-REVERSED-LINKS" => Some("MD011"),
-        "MD012" | "NO-MULTIPLE-BLANKS" => Some("MD012"),
-        "MD013" | "LINE-LENGTH" => Some("MD013"),
-        "MD014" | "COMMANDS-SHOW-OUTPUT" => Some("MD014"),
-        "MD015" | "NO-MISSING-SPACE-AFTER-LIST-MARKER" => Some("MD015"),
-        "MD018" | "NO-MISSING-SPACE-ATX" => Some("MD018"),
-        "MD019" | "NO-MULTIPLE-SPACE-ATX" => Some("MD019"),
-        "MD020" | "NO-MISSING-SPACE-CLOSED-ATX" => Some("MD020"),
-        "MD021" | "NO-MULTIPLE-SPACE-CLOSED-ATX" => Some("MD021"),
-        "MD022" | "BLANKS-AROUND-HEADINGS" => Some("MD022"),
-        "MD023" | "HEADING-START-LEFT" => Some("MD023"),
-        "MD024" | "NO-DUPLICATE-HEADING" => Some("MD024"),
-        "MD025" | "SINGLE-TITLE" | "SINGLE-H1" => Some("MD025"),
-        "MD026" | "NO-TRAILING-PUNCTUATION" => Some("MD026"),
-        "MD027" | "NO-MULTIPLE-SPACE-BLOCKQUOTE" => Some("MD027"),
-        "MD028" | "NO-BLANKS-BLOCKQUOTE" => Some("MD028"),
-        "MD029" | "OL-PREFIX" => Some("MD029"),
-        "MD030" | "LIST-MARKER-SPACE" => Some("MD030"),
-        "MD031" | "BLANKS-AROUND-FENCES" => Some("MD031"),
-        "MD032" | "BLANKS-AROUND-LISTS" => Some("MD032"),
-        "MD033" | "NO-INLINE-HTML" => Some("MD033"),
-        "MD034" | "NO-BARE-URLS" => Some("MD034"),
-        "MD035" | "HR-STYLE" => Some("MD035"),
-        "MD036" | "NO-EMPHASIS-AS-HEADING" => Some("MD036"),
-        "MD037" | "NO-SPACE-IN-EMPHASIS" => Some("MD037"),
-        "MD038" | "NO-SPACE-IN-CODE" => Some("MD038"),
-        "MD039" | "NO-SPACE-IN-LINKS" => Some("MD039"),
-        "MD040" | "FENCED-CODE-LANGUAGE" => Some("MD040"),
-        "MD041" | "FIRST-LINE-HEADING" | "FIRST-LINE-H1" => Some("MD041"),
-        "MD042" | "NO-EMPTY-LINKS" => Some("MD042"),
-        "MD043" | "REQUIRED-HEADINGS" => Some("MD043"),
-        "MD044" | "PROPER-NAMES" => Some("MD044"),
-        "MD045" | "NO-ALT-TEXT" => Some("MD045"),
-        "MD046" | "CODE-BLOCK-STYLE" => Some("MD046"),
-        "MD047" | "SINGLE-TRAILING-NEWLINE" => Some("MD047"),
-        "MD048" | "CODE-FENCE-STYLE" => Some("MD048"),
-        "MD049" | "EMPHASIS-STYLE" => Some("MD049"),
-        "MD050" | "STRONG-STYLE" => Some("MD050"),
-        "MD051" | "LINK-FRAGMENTS" => Some("MD051"),
-        "MD052" | "REFERENCE-LINKS-IMAGES" => Some("MD052"),
-        "MD053" | "LINK-IMAGE-REFERENCE-DEFINITIONS" => Some("MD053"),
-        "MD054" | "LINK-IMAGE-STYLE" => Some("MD054"),
-        "MD055" | "TABLE-PIPE-STYLE" => Some("MD055"),
-        "MD056" | "TABLE-COLUMN-COUNT" => Some("MD056"),
-        "MD057" | "EXISTING-RELATIVE-LINKS" => Some("MD057"),
-        "MD058" | "BLANKS-AROUND-TABLES" => Some("MD058"),
-        _ => None,
-    }
+/// Convert a rule name (which may be an alias like "line-length") to the canonical rule ID (like "MD013").
+/// Returns None if the rule name is not recognized.
+pub fn markdownlint_to_rumdl_rule_key(key: &str) -> Option<&'static str> {
+    // Use the shared alias resolution function from config module
+    crate::config::resolve_rule_name_alias(key)
 }
 
 fn normalize_toml_table_keys(val: toml::Value) -> toml::Value {
@@ -180,7 +125,7 @@ impl MarkdownlintConfig {
             let mapped = markdownlint_to_rumdl_rule_key(key);
             if let Some(rumdl_key) = mapped {
                 let norm_rule_key = rumdl_key.to_ascii_uppercase();
-                let toml_value: Option<toml::Value> = serde_yaml::from_value::<toml::Value>(value.clone()).ok();
+                let toml_value: Option<toml::Value> = serde_yml::from_value::<toml::Value>(value.clone()).ok();
                 let toml_value = toml_value.map(normalize_toml_table_keys);
                 let rule_config = sourced_config.rules.entry(norm_rule_key.clone()).or_default();
                 if let Some(tv) = toml_value {
@@ -305,7 +250,7 @@ impl MarkdownlintConfig {
                     }
                     continue;
                 }
-                let toml_value: Option<toml::Value> = serde_yaml::from_value::<toml::Value>(value.clone()).ok();
+                let toml_value: Option<toml::Value> = serde_yml::from_value::<toml::Value>(value.clone()).ok();
                 let toml_value = toml_value.map(normalize_toml_table_keys);
                 let rule_config = fragment.rules.entry(norm_rule_key.clone()).or_default();
                 if let Some(tv) = toml_value {
@@ -565,17 +510,17 @@ ul-style:
         let mut config_map = HashMap::new();
         config_map.insert(
             "MD013".to_string(),
-            serde_yaml::Value::Mapping({
-                let mut map = serde_yaml::Mapping::new();
+            serde_yml::Value::Mapping({
+                let mut map = serde_yml::Mapping::new();
                 map.insert(
-                    serde_yaml::Value::String("line_length".to_string()),
-                    serde_yaml::Value::Number(serde_yaml::Number::from(100)),
+                    serde_yml::Value::String("line_length".to_string()),
+                    serde_yml::Value::Number(serde_yml::Number::from(100)),
                 );
                 map
             }),
         );
-        config_map.insert("MD025".to_string(), serde_yaml::Value::Bool(true));
-        config_map.insert("MD026".to_string(), serde_yaml::Value::Bool(false));
+        config_map.insert("MD025".to_string(), serde_yml::Value::Bool(true));
+        config_map.insert("MD026".to_string(), serde_yml::Value::Bool(false));
 
         let mdl_config = MarkdownlintConfig(config_map);
         let sourced_config = mdl_config.map_to_sourced_rumdl_config(Some("test.json"));
@@ -599,23 +544,23 @@ ul-style:
         // Test line-length alias for MD013 with numeric value
         config_map.insert(
             "line-length".to_string(),
-            serde_yaml::Value::Number(serde_yaml::Number::from(120)),
+            serde_yml::Value::Number(serde_yml::Number::from(120)),
         );
 
         // Test rule disable (false)
-        config_map.insert("MD025".to_string(), serde_yaml::Value::Bool(false));
+        config_map.insert("MD025".to_string(), serde_yml::Value::Bool(false));
 
         // Test rule enable (true)
-        config_map.insert("MD026".to_string(), serde_yaml::Value::Bool(true));
+        config_map.insert("MD026".to_string(), serde_yml::Value::Bool(true));
 
         // Test another rule with configuration
         config_map.insert(
             "MD003".to_string(),
-            serde_yaml::Value::Mapping({
-                let mut map = serde_yaml::Mapping::new();
+            serde_yml::Value::Mapping({
+                let mut map = serde_yml::Mapping::new();
                 map.insert(
-                    serde_yaml::Value::String("style".to_string()),
-                    serde_yaml::Value::String("atx".to_string()),
+                    serde_yml::Value::String("style".to_string()),
+                    serde_yml::Value::String("atx".to_string()),
                 );
                 map
             }),
@@ -652,8 +597,8 @@ ul-style:
         assert!(sourced.rules.is_empty());
 
         // Test unknown rule (should be ignored)
-        config_map.insert("unknown-rule".to_string(), serde_yaml::Value::Bool(true));
-        config_map.insert("MD999".to_string(), serde_yaml::Value::Bool(true));
+        config_map.insert("unknown-rule".to_string(), serde_yml::Value::Bool(true));
+        config_map.insert("MD999".to_string(), serde_yml::Value::Bool(true));
 
         let config = MarkdownlintConfig(config_map);
         let sourced = config.map_to_sourced_rumdl_config(None);
@@ -667,13 +612,13 @@ ul-style:
         // Test MD044 with array configuration
         config_map.insert(
             "MD044".to_string(),
-            serde_yaml::Value::Mapping({
-                let mut map = serde_yaml::Mapping::new();
+            serde_yml::Value::Mapping({
+                let mut map = serde_yml::Mapping::new();
                 map.insert(
-                    serde_yaml::Value::String("names".to_string()),
-                    serde_yaml::Value::Sequence(vec![
-                        serde_yaml::Value::String("JavaScript".to_string()),
-                        serde_yaml::Value::String("GitHub".to_string()),
+                    serde_yml::Value::String("names".to_string()),
+                    serde_yml::Value::Sequence(vec![
+                        serde_yml::Value::String("JavaScript".to_string()),
+                        serde_yml::Value::String("GitHub".to_string()),
                     ]),
                 );
                 map
@@ -683,11 +628,11 @@ ul-style:
         // Test nested configuration
         config_map.insert(
             "MD003".to_string(),
-            serde_yaml::Value::Mapping({
-                let mut map = serde_yaml::Mapping::new();
+            serde_yml::Value::Mapping({
+                let mut map = serde_yml::Mapping::new();
                 map.insert(
-                    serde_yaml::Value::String("style".to_string()),
-                    serde_yaml::Value::String("atx".to_string()),
+                    serde_yml::Value::String("style".to_string()),
+                    serde_yml::Value::String("atx".to_string()),
                 );
                 map
             }),
@@ -718,19 +663,19 @@ ul-style:
         // Test different value types
         config_map.insert(
             "MD007".to_string(),
-            serde_yaml::Value::Number(serde_yaml::Number::from(4)),
+            serde_yml::Value::Number(serde_yml::Number::from(4)),
         ); // Simple number
         config_map.insert(
             "MD009".to_string(),
-            serde_yaml::Value::Mapping({
-                let mut map = serde_yaml::Mapping::new();
+            serde_yml::Value::Mapping({
+                let mut map = serde_yml::Mapping::new();
                 map.insert(
-                    serde_yaml::Value::String("br_spaces".to_string()),
-                    serde_yaml::Value::Number(serde_yaml::Number::from(2)),
+                    serde_yml::Value::String("br_spaces".to_string()),
+                    serde_yml::Value::Number(serde_yml::Number::from(2)),
                 );
                 map.insert(
-                    serde_yaml::Value::String("strict".to_string()),
-                    serde_yaml::Value::Bool(true),
+                    serde_yml::Value::String("strict".to_string()),
+                    serde_yml::Value::Bool(true),
                 );
                 map
             }),
@@ -765,7 +710,7 @@ ul-style:
             ("no-multiple-blanks", "MD012"),
             ("line-length", "MD013"),
             ("commands-show-output", "MD014"),
-            ("no-missing-space-after-list-marker", "MD015"),
+            // MD015-017 don't exist in markdownlint
             ("no-missing-space-atx", "MD018"),
             ("no-multiple-space-atx", "MD019"),
             ("no-missing-space-closed-atx", "MD020"),
@@ -809,6 +754,13 @@ ul-style:
             ("table-column-count", "MD056"),
             ("existing-relative-links", "MD057"),
             ("blanks-around-tables", "MD058"),
+            ("descriptive-link-text", "MD059"),
+            ("table-cell-alignment", "MD060"),
+            ("table-format", "MD060"),
+            ("forbidden-terms", "MD061"),
+            ("nested-code-fence", "MD070"),
+            ("blank-line-after-frontmatter", "MD071"),
+            ("frontmatter-key-sort", "MD072"),
         ];
 
         for (alias, expected) in aliases {
