@@ -3,26 +3,30 @@
 /// See [docs/md034.md](../../docs/md034.md) for full documentation, configuration, and examples.
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::range_utils::{LineIndex, calculate_url_range};
-use crate::utils::regex_cache::{EMAIL_PATTERN, get_cached_regex};
+use crate::utils::regex_cache::{
+    EMAIL_PATTERN, URL_IPV6_STR, URL_QUICK_CHECK_STR, URL_STANDARD_STR, URL_WWW_STR, XMPP_URI_STR,
+    get_cached_fancy_regex, get_cached_regex,
+};
 
 use crate::filtered_lines::FilteredLinesExt;
 use crate::lint_context::LintContext;
 
-// URL detection patterns
-const URL_QUICK_CHECK_STR: &str = r#"(?:https?|ftps?)://|@"#;
+// MD034-specific patterns for markdown constructs
+// Core URL patterns (URL_QUICK_CHECK_STR, URL_STANDARD_STR, etc.) are imported from regex_cache
 const CUSTOM_PROTOCOL_PATTERN_STR: &str = r#"(?:grpc|ws|wss|ssh|git|svn|file|data|javascript|vscode|chrome|about|slack|discord|matrix|irc|redis|mongodb|postgresql|mysql|kafka|nats|amqp|mqtt|custom|app|api|service)://"#;
 const MARKDOWN_LINK_PATTERN_STR: &str = r#"\[(?:[^\[\]]|\[[^\]]*\])*\]\(([^)\s]+)(?:\s+(?:\"[^\"]*\"|\'[^\']*\'))?\)"#;
 const MARKDOWN_EMPTY_LINK_PATTERN_STR: &str = r#"\[(?:[^\[\]]|\[[^\]]*\])*\]\(\)"#;
 const MARKDOWN_EMPTY_REF_PATTERN_STR: &str = r#"\[(?:[^\[\]]|\[[^\]]*\])*\]\[\]"#;
+// Pattern for links in angle brackets - excludes HTTP(S), FTP(S), XMPP URIs, and emails
 const ANGLE_LINK_PATTERN_STR: &str =
-    r#"<((?:https?|ftps?)://(?:\[[0-9a-fA-F:]+(?:%[a-zA-Z0-9]+)?\]|[^>]+)|[^@\s]+@[^@\s]+\.[^@\s>]+)>"#;
+    r#"<((?:https?|ftps?)://(?:\[[0-9a-fA-F:]+(?:%[a-zA-Z0-9]+)?\]|[^>]+)|xmpp:[^>]+|[^@\s]+@[^@\s]+\.[^@\s>]+)>"#;
 const BADGE_LINK_LINE_STR: &str = r#"^\s*\[!\[[^\]]*\]\([^)]*\)\]\([^)]*\)\s*$"#;
 const MARKDOWN_IMAGE_PATTERN_STR: &str = r#"!\s*\[([^\]]*)\]\s*\(([^)\s]+)(?:\s+(?:\"[^\"]*\"|\'[^\']*\'))?\)"#;
-const SIMPLE_URL_REGEX_STR: &str = r#"(https?|ftps?)://(?:\[[0-9a-fA-F:%.]+\](?::\d+)?|[^\s<>\[\]()\\'\"`\]]+)(?:/[^\s<>\[\]()\\'\"`]*)?(?:\?[^\s<>\[\]()\\'\"`]*)?(?:#[^\s<>\[\]()\\'\"`]*)?"#;
-const IPV6_URL_REGEX_STR: &str = r#"(https?|ftps?)://\[[0-9a-fA-F:%.\-a-zA-Z]+\](?::\d+)?(?:/[^\s<>\[\]()\\'\"`]*)?(?:\?[^\s<>\[\]()\\'\"`]*)?(?:#[^\s<>\[\]()\\'\"`]*)?"#;
-const REFERENCE_DEF_RE_STR: &str = r"^\s*\[[^\]]+\]:\s*(?:https?|ftps?)://\S+$";
-const HTML_TAG_PATTERN_STR: &str = r#"<[^>]*>"#;
+// Reference definition pattern - matches [label]: URL with optional title
+const REFERENCE_DEF_RE_STR: &str = r"^\s*\[[^\]]+\]:\s*(?:<|(?:https?|ftps?)://)";
 const MULTILINE_LINK_CONTINUATION_STR: &str = r#"^[^\[]*\]\(.*\)"#;
+// Pattern to match shortcut/collapsed reference links: [text] or [text][]
+const SHORTCUT_REF_PATTERN_STR: &str = r#"\[([^\[\]]+)\](?!\s*[\[(])"#;
 
 /// Reusable buffers for check_line to reduce allocations
 #[derive(Default)]
@@ -38,10 +42,13 @@ pub struct MD034NoBareUrls;
 impl MD034NoBareUrls {
     #[inline]
     pub fn should_skip_content(&self, content: &str) -> bool {
-        // Skip if content has no URLs and no email addresses
-        // Fast byte scanning for common URL/email indicators
+        // Skip if content has no URLs, XMPP URIs, or email addresses
+        // Fast byte scanning for common URL/email/xmpp indicators
         let bytes = content.as_bytes();
-        !bytes.contains(&b':') && !bytes.contains(&b'@')
+        let has_colon = bytes.contains(&b':');
+        let has_at = bytes.contains(&b'@');
+        let has_www = content.contains("www.");
+        !has_colon && !has_at && !has_www
     }
 
     /// Remove trailing punctuation that is likely sentence punctuation, not part of the URL
@@ -57,14 +64,14 @@ impl MD034NoBareUrls {
             let mut balance = 0;
             let mut last_balanced_pos = url.len();
 
-            for (i, c) in url.chars().enumerate() {
+            for (byte_idx, c) in url.char_indices() {
                 if c == '(' {
                     balance += 1;
                 } else if c == ')' {
                     balance -= 1;
                     if balance < 0 {
                         // Found an unmatched closing paren
-                        last_balanced_pos = i;
+                        last_balanced_pos = byte_idx;
                         break;
                     }
                 }
@@ -98,19 +105,6 @@ impl MD034NoBareUrls {
             .unwrap_or(false)
     }
 
-    /// Check if a position in a line is inside an HTML tag
-    fn is_in_html_tag(&self, line: &str, pos: usize) -> bool {
-        // Find all HTML tags in the line
-        if let Ok(re) = get_cached_regex(HTML_TAG_PATTERN_STR) {
-            for mat in re.find_iter(line) {
-                if pos >= mat.start() && pos < mat.end() {
-                    return true;
-                }
-            }
-        }
-        false
-    }
-
     fn check_line(
         &self,
         line: &str,
@@ -127,6 +121,11 @@ impl MD034NoBareUrls {
             return warnings;
         }
 
+        // Skip lines inside HTML blocks - URLs in HTML attributes should not be linted
+        if ctx.line_info(line_number).is_some_and(|info| info.in_html_block) {
+            return warnings;
+        }
+
         // Skip lines that are continuations of multiline markdown links
         // Pattern: text](url) without a leading [
         if let Ok(re) = get_cached_regex(MULTILINE_LINK_CONTINUATION_STR)
@@ -136,10 +135,13 @@ impl MD034NoBareUrls {
         }
 
         // Quick check - does this line potentially have a URL or email?
-        if let Ok(re) = get_cached_regex(URL_QUICK_CHECK_STR)
-            && !re.is_match(line)
-            && !line.contains('@')
-        {
+        let has_quick_check = get_cached_regex(URL_QUICK_CHECK_STR)
+            .map(|re| re.is_match(line))
+            .unwrap_or(false);
+        let has_www = line.contains("www.");
+        let has_at = line.contains('@');
+
+        if !has_quick_check && !has_at && !has_www {
             return warnings;
         }
 
@@ -166,6 +168,15 @@ impl MD034NoBareUrls {
             }
         }
 
+        // Also exclude shortcut reference links like [URL] - even if no definition exists,
+        // the brackets indicate user intent to use markdown formatting
+        // Uses fancy_regex for negative lookahead support
+        if let Ok(re) = get_cached_fancy_regex(SHORTCUT_REF_PATTERN_STR) {
+            for mat in re.find_iter(line).flatten() {
+                buffers.markdown_link_ranges.push((mat.start(), mat.end()));
+            }
+        }
+
         if let Ok(re) = get_cached_regex(ANGLE_LINK_PATTERN_STR) {
             for cap in re.captures_iter(line) {
                 if let Some(mat) = cap.get(0) {
@@ -197,7 +208,7 @@ impl MD034NoBareUrls {
         buffers.urls_found.clear();
 
         // First, find IPv6 URLs (they need special handling)
-        if let Ok(re) = get_cached_regex(IPV6_URL_REGEX_STR) {
+        if let Ok(re) = get_cached_regex(URL_IPV6_STR) {
             for mat in re.find_iter(line) {
                 let url_str = mat.as_str();
                 buffers.urls_found.push((mat.start(), mat.end(), url_str.to_string()));
@@ -205,7 +216,7 @@ impl MD034NoBareUrls {
         }
 
         // Then find regular URLs
-        if let Ok(re) = get_cached_regex(SIMPLE_URL_REGEX_STR) {
+        if let Ok(re) = get_cached_regex(URL_STANDARD_STR) {
             for mat in re.find_iter(line) {
                 let url_str = mat.as_str();
 
@@ -234,8 +245,56 @@ impl MD034NoBareUrls {
             }
         }
 
+        // Find www URLs without protocol (e.g., www.example.com)
+        if let Ok(re) = get_cached_regex(URL_WWW_STR) {
+            for mat in re.find_iter(line) {
+                let url_str = mat.as_str();
+                let start_pos = mat.start();
+                let end_pos = mat.end();
+
+                // Skip if preceded by / or @ (likely part of a full URL)
+                if start_pos > 0 {
+                    let prev_char = line.as_bytes().get(start_pos - 1).copied();
+                    if prev_char == Some(b'/') || prev_char == Some(b'@') {
+                        continue;
+                    }
+                }
+
+                // Skip if inside angle brackets (autolink syntax like <www.example.com>)
+                if start_pos > 0 && end_pos < line.len() {
+                    let prev_char = line.as_bytes().get(start_pos - 1).copied();
+                    let next_char = line.as_bytes().get(end_pos).copied();
+                    if prev_char == Some(b'<') && next_char == Some(b'>') {
+                        continue;
+                    }
+                }
+
+                buffers.urls_found.push((start_pos, end_pos, url_str.to_string()));
+            }
+        }
+
+        // Find XMPP URIs (GFM extended autolinks: xmpp:user@domain/resource)
+        if let Ok(re) = get_cached_regex(XMPP_URI_STR) {
+            for mat in re.find_iter(line) {
+                let uri_str = mat.as_str();
+                let start_pos = mat.start();
+                let end_pos = mat.end();
+
+                // Skip if inside angle brackets (already properly formatted: <xmpp:user@domain>)
+                if start_pos > 0 && end_pos < line.len() {
+                    let prev_char = line.as_bytes().get(start_pos - 1).copied();
+                    let next_char = line.as_bytes().get(end_pos).copied();
+                    if prev_char == Some(b'<') && next_char == Some(b'>') {
+                        continue;
+                    }
+                }
+
+                buffers.urls_found.push((start_pos, end_pos, uri_str.to_string()));
+            }
+        }
+
         // Process found URLs
-        for &(start, end, ref url_str) in buffers.urls_found.iter() {
+        for &(start, _end, ref url_str) in buffers.urls_found.iter() {
             // Skip custom protocols
             if get_cached_regex(CUSTOM_PROTOCOL_PATTERN_STR)
                 .map(|re| re.is_match(url_str))
@@ -245,16 +304,19 @@ impl MD034NoBareUrls {
             }
 
             // Check if this URL is inside a markdown link, angle bracket, or image
+            // We check if the URL starts within a construct, not if it's entirely contained.
+            // This handles cases where URL detection may include trailing characters
+            // that extend past the construct boundary (e.g., parentheses).
             let mut is_inside_construct = false;
             for &(link_start, link_end) in buffers.markdown_link_ranges.iter() {
-                if start >= link_start && end <= link_end {
+                if start >= link_start && start < link_end {
                     is_inside_construct = true;
                     break;
                 }
             }
 
             for &(img_start, img_end) in buffers.image_ranges.iter() {
-                if start >= img_start && end <= img_end {
+                if start >= img_start && start < img_end {
                     is_inside_construct = true;
                     break;
                 }
@@ -264,18 +326,25 @@ impl MD034NoBareUrls {
                 continue;
             }
 
-            // Check if URL is inside an HTML tag
-            if self.is_in_html_tag(line, start) {
+            // Calculate absolute byte position for context-aware checks
+            let line_start_byte = line_index.get_line_start_byte(line_number).unwrap_or(0);
+            let absolute_pos = line_start_byte + start;
+
+            // Check if URL is inside an HTML tag (handles multiline tags correctly)
+            if ctx.is_in_html_tag(absolute_pos) {
                 continue;
             }
 
             // Check if we're inside an HTML comment
-            let line_start_byte = line_index.get_line_start_byte(line_number).unwrap_or(0);
-            let absolute_pos = line_start_byte + start;
             if ctx.is_in_html_comment(absolute_pos) {
                 continue;
             }
 
+            // Check if we're inside a Hugo/Quarto shortcode
+            if ctx.is_in_shortcode(absolute_pos) {
+                continue;
+            }
+
             // Clean up the URL by removing trailing punctuation
             let trimmed_url = self.trim_trailing_punctuation(url_str);
 
@@ -285,6 +354,13 @@ impl MD034NoBareUrls {
                 let (start_line, start_col, end_line, end_col) =
                     calculate_url_range(line_number, line, start, trimmed_len);
 
+                // For www URLs without protocol, add https:// prefix in the fix
+                let replacement = if trimmed_url.starts_with("www.") {
+                    format!("<https://{trimmed_url}>")
+                } else {
+                    format!("<{trimmed_url}>")
+                };
+
                 warnings.push(LintWarning {
                     rule_name: Some("MD034".to_string()),
                     line: start_line,
@@ -298,7 +374,7 @@ impl MD034NoBareUrls {
                             let line_start_byte = line_index.get_line_start_byte(line_number).unwrap_or(0);
                             (line_start_byte + start)..(line_start_byte + start + trimmed_len)
                         },
-                        replacement: format!("<{trimmed_url}>"),
+                        replacement,
                     }),
                 });
             }
@@ -311,6 +387,12 @@ impl MD034NoBareUrls {
                 let start = mat.start();
                 let end = mat.end();
 
+                // Skip if email is part of an XMPP URI (xmpp:user@domain)
+                // Check character boundary to avoid panics with multi-byte UTF-8
+                if start >= 5 && line.is_char_boundary(start - 5) && &line[start - 5..start] == "xmpp:" {
+                    continue;
+                }
+
                 // Check if email is inside angle brackets or markdown link
                 let mut is_inside_construct = false;
                 for &(link_start, link_end) in buffers.markdown_link_ranges.iter() {
@@ -321,8 +403,12 @@ impl MD034NoBareUrls {
                 }
 
                 if !is_inside_construct {
-                    // Check if email is inside an HTML tag
-                    if self.is_in_html_tag(line, start) {
+                    // Calculate absolute byte position for context-aware checks
+                    let line_start_byte = line_index.get_line_start_byte(line_number).unwrap_or(0);
+                    let absolute_pos = line_start_byte + start;
+
+                    // Check if email is inside an HTML tag (handles multiline tags)
+                    if ctx.is_in_html_tag(absolute_pos) {
                         continue;
                     }
 
@@ -345,10 +431,7 @@ impl MD034NoBareUrls {
                             message: format!("Email address without angle brackets or link formatting: '{email}'"),
                             severity: Severity::Warning,
                             fix: Some(Fix {
-                                range: {
-                                    let line_start_byte = line_index.get_line_start_byte(line_number).unwrap_or(0);
-                                    (line_start_byte + start)..(line_start_byte + end)
-                                },
+                                range: (line_start_byte + start)..(line_start_byte + end),
                                 replacement: format!("<{email}>"),
                             }),
                         });
@@ -427,6 +510,20 @@ impl Rule for MD034NoBareUrls {
                 })
             });
 
+            // Filter out warnings where the URL is inside a parsed link
+            // This handles cases like [text]( https://url ) where the URL has leading whitespace
+            // pulldown-cmark correctly parses these as valid links even though our regex misses them
+            line_warnings.retain(|warning| {
+                if let Some(fix) = &warning.fix {
+                    // Check if the fix range falls inside any parsed link's byte range
+                    !ctx.links
+                        .iter()
+                        .any(|link| fix.range.start >= link.byte_offset && fix.range.end <= link.byte_end)
+                } else {
+                    true
+                }
+            });
+
             warnings.extend(line_warnings);
         }
 
