@@ -1,12 +1,15 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
 use crate::utils::mkdocs_patterns::is_mkdocs_auto_reference;
-use pulldown_cmark::LinkType;
 
 /// Rule MD042: No empty links
 ///
 /// See [docs/md042.md](../../docs/md042.md) for full documentation, configuration, and examples.
 ///
-/// This rule is triggered when a link has no content (text) or destination (URL).
+/// This rule is triggered when a link has no destination (URL).
+/// "Empty links do not lead anywhere and therefore don't function as links."
+///
+/// Note: Empty TEXT with a valid URL (e.g., `[](url)`) is NOT flagged by MD042.
+/// While this may be an accessibility concern, it's not an "empty link" per se.
 ///
 /// # MkDocs Support
 ///
@@ -142,6 +145,7 @@ impl Rule for MD042NoEmptyLinks {
 
         // Check if we're in MkDocs mode from the context
         let mkdocs_mode = ctx.flavor == crate::config::MarkdownFlavor::MkDocs;
+        let quarto_mode = ctx.flavor == crate::config::MarkdownFlavor::Quarto;
 
         // Use centralized link parsing from LintContext
         for link in &ctx.links {
@@ -150,6 +154,18 @@ impl Rule for MD042NoEmptyLinks {
                 continue;
             }
 
+            // Skip Quarto/Pandoc citations ([@citation], @citation)
+            // Citations look like reference links but are bibliography references
+            if quarto_mode && ctx.is_in_citation(link.byte_offset) {
+                continue;
+            }
+
+            // Skip links inside shortcodes ({{< ... >}} or {{% ... %}})
+            // Shortcodes may contain template syntax that looks like links
+            if ctx.is_in_shortcode(link.byte_offset) {
+                continue;
+            }
+
             // Skip links inside HTML tags (e.g., <a href="...?p[images][0]=...">)
             // Check if the link's byte position falls within any HTML tag range
             let in_html_tag = ctx
@@ -160,15 +176,23 @@ impl Rule for MD042NoEmptyLinks {
                 continue;
             }
 
-            // For reference links, resolve the URL
-            let effective_url = if link.is_reference {
+            // For reference links with defined references, we don't flag them as empty
+            // even if the URL happens to be missing. Undefined references are handled by MD052.
+            // MD042 only flags:
+            // - Empty text: `[][ref]`, `[](url)`
+            // - Empty URL in inline links: `[text]()`
+            // NOT: `[text][undefined]` (that's MD052's job)
+            let (effective_url, is_undefined_reference): (&str, bool) = if link.is_reference {
                 if let Some(ref_id) = &link.reference_id {
-                    ctx.get_reference_url(ref_id.as_ref()).unwrap_or("").to_string()
+                    match ctx.get_reference_url(ref_id.as_ref()) {
+                        Some(url) => (url, false),
+                        None => ("", true), // Mark as undefined reference
+                    }
                 } else {
-                    String::new()
+                    ("", false) // Empty reference like `[][]`
                 }
             } else {
-                link.url.to_string()
+                (&link.url, false)
             };
 
             // For MkDocs mode, check if this looks like an auto-reference
@@ -205,22 +229,37 @@ impl Rule for MD042NoEmptyLinks {
                 continue;
             }
 
-            // Skip Obsidian block references (wiki-links with #^ pattern)
-            // Examples: [[#^block-id]] or [[Note#^block-id]]
-            // These are valid Obsidian syntax where the display text is auto-generated from the referenced block
-            if matches!(link.link_type, LinkType::WikiLink { .. })
-                && link.text.trim().is_empty()
-                && link.url.contains("#^")
+            // Skip wiki-style links (Obsidian/Notion syntax: [[Page Name]] or [[Page|Display]])
+            // Wiki links are valid syntax and should never be flagged as "empty links".
+            // This covers all wiki link patterns including:
+            // - Basic: [[Page Name]]
+            // - With path: [[Folder/Page]]
+            // - With alias: [[Page|Display Text]]
+            // - With heading: [[Page#heading]]
+            // - Block references: [[Page#^block-id]] or [[#^block-id]]
+            //
+            // Detection: pulldown-cmark captures [[Example] as bytes 0..10, with trailing ] at byte 10
+            // We check: starts with "[[" AND the char after byte_end is "]"
+            if link_markdown.starts_with("[[")
+                && link_markdown.ends_with(']')
+                && ctx.content.as_bytes().get(link.byte_end) == Some(&b']')
             {
                 continue;
             }
 
-            // Check for empty links
-            if link.text.trim().is_empty() || effective_url.trim().is_empty() {
+            // Skip undefined references - those are handled by MD052, not MD042
+            // MD042 is only for truly empty links, not missing reference definitions
+            if is_undefined_reference && !link.text.trim().is_empty() {
+                continue;
+            }
+
+            // Check for empty destination (URL) only
+            // MD042 is about links that "do not lead anywhere" - focusing on empty destinations
+            // Empty text with valid URL is NOT flagged (that's an accessibility concern, not "empty link")
+            if effective_url.trim().is_empty() {
                 // In MkDocs mode, check if this is an attribute anchor: []() followed by { #anchor }
                 if mkdocs_mode
                     && link.text.trim().is_empty()
-                    && effective_url.trim().is_empty()
                     && Self::is_mkdocs_attribute_anchor(ctx.content, link.byte_end)
                 {
                     // This is a valid MkDocs attribute anchor, skip it
@@ -228,29 +267,8 @@ impl Rule for MD042NoEmptyLinks {
                 }
 
                 // Determine if we can provide a meaningful fix
-                let replacement = if link.text.trim().is_empty() {
-                    // Empty text - can we fix it?
-                    if !effective_url.trim().is_empty() {
-                        // Has URL but no text - add placeholder text
-                        if link.is_reference {
-                            Some(format!(
-                                "[Link text]{}",
-                                &ctx.content[link.byte_offset + 1..link.byte_end]
-                            ))
-                        } else {
-                            Some(format!("[Link text]({effective_url})"))
-                        }
-                    } else {
-                        // Both empty - can't meaningfully auto-fix
-                        None
-                    }
-                } else if link.is_reference {
-                    // Reference links with text but no/empty reference - keep the format
-                    let ref_part = &ctx.content[link.byte_offset + link.text.len() + 2..link.byte_end];
-                    Some(format!("[{}]{}", link.text, ref_part))
-                } else {
-                    // URL is empty, but text is not
-                    // Check if the link text looks like a URL - if so, use it as the destination
+                // Check if the link text looks like a URL - if so, use it as the destination
+                let replacement = if !link.text.trim().is_empty() {
                     let text_is_url = link.text.starts_with("http://")
                         || link.text.starts_with("https://")
                         || link.text.starts_with("ftp://")
@@ -262,6 +280,9 @@ impl Rule for MD042NoEmptyLinks {
                         // Text is not a URL - can't meaningfully auto-fix
                         None
                     }
+                } else {
+                    // Both empty - can't meaningfully auto-fix
+                    None
                 };
 
                 // Extract the exact link text from the source
@@ -274,7 +295,7 @@ impl Rule for MD042NoEmptyLinks {
                     column: link.start_col + 1, // Convert to 1-indexed
                     end_line: link.line,
                     end_column: link.end_col + 1, // Convert to 1-indexed
-                    severity: Severity::Warning,
+                    severity: Severity::Error,
                     fix: replacement.map(|r| Fix {
                         range: link.byte_offset..link.byte_end,
                         replacement: r,
@@ -347,6 +368,7 @@ mod tests {
         let ctx = LintContext::new(
             "[valid link](https://example.com)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
@@ -355,99 +377,127 @@ mod tests {
         let ctx = LintContext::new(
             "[another valid link](path/to/page.html)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Links with text and relative URLs should pass");
     }
 
     #[test]
-    fn test_links_with_empty_text_should_fail() {
-        let ctx = LintContext::new("[](https://example.com)", crate::config::MarkdownFlavor::Standard);
+    fn test_links_with_empty_text_but_valid_url_pass() {
+        // MD042 only flags empty URLs, not empty text
+        // "Empty links do not lead anywhere" - these links DO lead somewhere
+        let ctx = LintContext::new("[](https://example.com)", crate::config::MarkdownFlavor::Standard, None);
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
-        assert_eq!(result[0].message, "Empty link found: [](https://example.com)");
-        assert_eq!(result[0].line, 1);
-        assert_eq!(result[0].column, 1);
+        assert!(
+            result.is_empty(),
+            "Empty text with valid URL should NOT be flagged by MD042. Got: {result:?}"
+        );
     }
 
     #[test]
-    fn test_links_with_only_whitespace_should_fail() {
-        let ctx = LintContext::new("[   ](https://example.com)", crate::config::MarkdownFlavor::Standard);
+    fn test_links_with_only_whitespace_but_valid_url_pass() {
+        // MD042 only flags empty URLs, not empty/whitespace text
+        let ctx = LintContext::new(
+            "[   ](https://example.com)",
+            crate::config::MarkdownFlavor::Standard,
+            None,
+        );
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
-        assert_eq!(result[0].message, "Empty link found: [   ](https://example.com)");
+        assert!(
+            result.is_empty(),
+            "Whitespace text with valid URL should NOT be flagged. Got: {result:?}"
+        );
 
-        let ctx = LintContext::new("[\t\n](https://example.com)", crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(
+            "[\t\n](https://example.com)",
+            crate::config::MarkdownFlavor::Standard,
+            None,
+        );
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
-        assert_eq!(result[0].message, "Empty link found: [\t\n](https://example.com)");
+        assert!(
+            result.is_empty(),
+            "Whitespace text with valid URL should NOT be flagged. Got: {result:?}"
+        );
     }
 
     #[test]
-    fn test_reference_links_with_empty_text() {
+    fn test_reference_links_with_empty_text_but_valid_ref() {
+        // Empty text with valid reference (has URL) should NOT be flagged
+        // MD042 only flags empty URLs, not empty text
         let ctx = LintContext::new(
             "[][ref]\n\n[ref]: https://example.com",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
-        assert_eq!(result[0].message, "Empty link found: [][ref]");
-        assert_eq!(result[0].line, 1);
-
-        // Empty text with empty reference
-        let ctx = LintContext::new(
-            "[][]\n\n[]: https://example.com",
-            crate::config::MarkdownFlavor::Standard,
+        assert!(
+            result.is_empty(),
+            "Empty text with valid reference should NOT be flagged. Got: {result:?}"
         );
-        let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
+
+        // Note: `[]:` (empty reference label) is NOT valid CommonMark
+        // So we don't test that case - empty labels are not supported
     }
 
     #[test]
     fn test_images_should_be_ignored() {
         // Images can have empty alt text, so they should not trigger the rule
-        let ctx = LintContext::new("![](image.png)", crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new("![](image.png)", crate::config::MarkdownFlavor::Standard, None);
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Images with empty alt text should be ignored");
 
-        let ctx = LintContext::new("![   ](image.png)", crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new("![   ](image.png)", crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Images with whitespace alt text should be ignored");
     }
 
     #[test]
     fn test_links_with_nested_formatting() {
-        // Links with nested formatting but empty effective text
-        // Note: [**] contains "**" as text, which is not empty after trimming
-        let ctx = LintContext::new("[**](https://example.com)", crate::config::MarkdownFlavor::Standard);
+        // MD042 only flags empty URLs - all of these have valid URLs so they pass
         let rule = MD042NoEmptyLinks::new();
-        let result = rule.check(&ctx).unwrap();
-        assert!(result.is_empty(), "[**] is not considered empty since ** is text");
 
-        let ctx = LintContext::new("[__](https://example.com)", crate::config::MarkdownFlavor::Standard);
+        // [**] contains "**" as text, has URL → pass
+        let ctx = LintContext::new(
+            "[**](https://example.com)",
+            crate::config::MarkdownFlavor::Standard,
+            None,
+        );
         let result = rule.check(&ctx).unwrap();
-        assert!(result.is_empty(), "[__] is not considered empty since __ is text");
+        assert!(result.is_empty(), "[**](url) has URL so should pass");
 
-        // Links with truly empty formatting should fail
-        let ctx = LintContext::new("[](https://example.com)", crate::config::MarkdownFlavor::Standard);
+        // [__] contains "__" as text, has URL → pass
+        let ctx = LintContext::new(
+            "[__](https://example.com)",
+            crate::config::MarkdownFlavor::Standard,
+            None,
+        );
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
+        assert!(result.is_empty(), "[__](url) has URL so should pass");
 
-        // Links with nested formatting and actual text should pass
+        // [](url) - empty text but has URL → pass (per markdownlint behavior)
+        let ctx = LintContext::new("[](https://example.com)", crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert!(result.is_empty(), "[](url) has URL so should pass");
+
+        // [**bold text**](url) - has text and URL → pass
         let ctx = LintContext::new(
             "[**bold text**](https://example.com)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Links with nested formatting and text should pass");
 
+        // [*italic* and **bold**](url) - has text and URL → pass
         let ctx = LintContext::new(
             "[*italic* and **bold**](https://example.com)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Links with multiple nested formatting should pass");
@@ -455,109 +505,133 @@ mod tests {
 
     #[test]
     fn test_multiple_empty_links_on_same_line() {
+        // MD042 only flags empty URLs - all these have URLs so they pass
         let ctx = LintContext::new(
             "[](url1) and [](url2) and [valid](url3)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 2, "Should detect both empty links");
-        assert_eq!(result[0].column, 1);
-        assert_eq!(result[1].column, 14);
+        assert!(
+            result.is_empty(),
+            "Empty text with valid URL should NOT be flagged. Got: {result:?}"
+        );
+
+        // Test multiple truly empty links (empty URL)
+        let ctx = LintContext::new(
+            "[text1]() and [text2]() and [text3](url)",
+            crate::config::MarkdownFlavor::Standard,
+            None,
+        );
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 2, "Should detect both empty URL links");
+        assert_eq!(result[0].column, 1); // [text1]()
+        assert_eq!(result[1].column, 15); // [text2]()
     }
 
     #[test]
     fn test_escaped_brackets() {
         // Escaped brackets should not be treated as links
-        let ctx = LintContext::new("\\[\\](https://example.com)", crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(
+            "\\[\\](https://example.com)",
+            crate::config::MarkdownFlavor::Standard,
+            None,
+        );
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Escaped brackets should not be treated as links");
 
         // But this should still be a link
-        let ctx = LintContext::new("[\\[\\]](https://example.com)", crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(
+            "[\\[\\]](https://example.com)",
+            crate::config::MarkdownFlavor::Standard,
+            None,
+        );
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Link with escaped brackets in text should pass");
     }
 
     #[test]
     fn test_links_in_lists_and_blockquotes() {
-        // Empty links in lists
+        // MD042 only flags empty URLs - [](url) has URL so it passes
+        let rule = MD042NoEmptyLinks::new();
+
+        // Empty text with URL in lists - passes (has URL)
         let ctx = LintContext::new(
             "- [](https://example.com)\n- [valid](https://example.com)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
-        let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
-        assert_eq!(result[0].line, 1);
+        assert!(result.is_empty(), "[](url) in lists should pass");
 
-        // Empty links in blockquotes
+        // Empty text with URL in blockquotes - passes (has URL)
         let ctx = LintContext::new(
             "> [](https://example.com)\n> [valid](https://example.com)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
-        assert_eq!(result[0].line, 1);
+        assert!(result.is_empty(), "[](url) in blockquotes should pass");
 
-        // Nested structures
+        // Empty URL in lists - FAILS (no URL)
         let ctx = LintContext::new(
-            "> - [](url1)\n> - [text](url2)",
+            "- [text]()\n- [valid](url)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1);
+        assert_eq!(result.len(), 1, "Empty URL should be flagged");
+        assert_eq!(result[0].line, 1);
     }
 
     #[test]
     fn test_unicode_whitespace_characters() {
-        // Non-breaking space (U+00A0) - IS considered whitespace by Rust's trim()
+        // MD042 only flags empty URLs - all these have URLs so they pass
+        // regardless of the text content (whitespace or not)
+        let rule = MD042NoEmptyLinks::new();
+
+        // Non-breaking space (U+00A0) - has URL, passes
         let ctx = LintContext::new(
             "[\u{00A0}](https://example.com)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
-        let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1, "Non-breaking space should be treated as whitespace");
+        assert!(result.is_empty(), "Has URL, should pass regardless of text");
 
-        // Em space (U+2003) - IS considered whitespace by Rust's trim()
+        // Em space (U+2003) - has URL, passes
         let ctx = LintContext::new(
             "[\u{2003}](https://example.com)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1, "Em space should be treated as whitespace");
+        assert!(result.is_empty(), "Has URL, should pass regardless of text");
 
-        // Zero-width space (U+200B) - NOT considered whitespace by Rust's trim()
-        // This is a formatting character, not a whitespace character
+        // Zero-width space (U+200B) - has URL, passes
         let ctx = LintContext::new(
             "[\u{200B}](https://example.com)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let result = rule.check(&ctx).unwrap();
-        assert!(
-            result.is_empty(),
-            "Zero-width space is not considered whitespace by trim()"
-        );
+        assert!(result.is_empty(), "Has URL, should pass regardless of text");
 
-        // Test with zero-width space between spaces
-        // Since trim() doesn't consider zero-width space as whitespace,
-        // " \u{200B} " becomes "\u{200B}" after trimming, which is NOT empty
+        // Test with zero-width space between spaces - has URL, passes
         let ctx = LintContext::new(
             "[ \u{200B} ](https://example.com)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let result = rule.check(&ctx).unwrap();
-        assert!(
-            result.is_empty(),
-            "Zero-width space remains after trim(), so link is not empty"
-        );
+        assert!(result.is_empty(), "Has URL, should pass regardless of text");
     }
 
     #[test]
     fn test_empty_url_with_text() {
-        let ctx = LintContext::new("[some text]()", crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new("[some text]()", crate::config::MarkdownFlavor::Standard, None);
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
@@ -566,7 +640,7 @@ mod tests {
 
     #[test]
     fn test_both_empty_text_and_url() {
-        let ctx = LintContext::new("[]()", crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new("[]()", crate::config::MarkdownFlavor::Standard, None);
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
         assert_eq!(result.len(), 1);
@@ -575,10 +649,20 @@ mod tests {
 
     #[test]
     fn test_reference_link_with_undefined_reference() {
-        let ctx = LintContext::new("[text][undefined]", crate::config::MarkdownFlavor::Standard);
+        // Undefined references are handled by MD052, not MD042
+        // MD042 should NOT flag [text][undefined] - it's not an "empty link"
+        let ctx = LintContext::new("[text][undefined]", crate::config::MarkdownFlavor::Standard, None);
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1, "Undefined reference should be treated as empty URL");
+        assert!(
+            result.is_empty(),
+            "MD042 should NOT flag [text][undefined] - undefined refs are MD052's job. Got: {result:?}"
+        );
+
+        // But empty text with undefined reference SHOULD be flagged
+        let ctx = LintContext::new("[][undefined]", crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Empty text in reference link should still be flagged");
     }
 
     #[test]
@@ -589,23 +673,20 @@ mod tests {
         let ctx = LintContext::new(
             "[example][]\n\n[example]: https://example.com",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
         assert!(result.is_empty(), "Valid implicit reference link should pass");
 
-        // Empty implicit reference link
-        let ctx = LintContext::new(
-            "[][]\n\n[]: https://example.com",
-            crate::config::MarkdownFlavor::Standard,
-        );
-        let result = rule.check(&ctx).unwrap();
-        assert_eq!(result.len(), 1, "Empty implicit reference link should fail");
+        // Note: `[]:` (empty reference label) is NOT valid CommonMark
+        // Empty labels are not supported, so we don't test `[][]\n\n[]: url`
 
         // Test actual shortcut-style links are not detected (since they don't match the pattern)
         let ctx = LintContext::new(
             "[example]\n\n[example]: https://example.com",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let result = rule.check(&ctx).unwrap();
         assert!(
@@ -616,38 +697,41 @@ mod tests {
 
     #[test]
     fn test_fix_suggestions() {
+        // MD042 only flags empty URLs now
         let rule = MD042NoEmptyLinks::new();
 
-        // Case 1: Empty text, has URL - fixable (add placeholder text)
-        let ctx = LintContext::new("[](https://example.com)", crate::config::MarkdownFlavor::Standard);
+        // Case 1: Empty text, has URL - NOT flagged (has URL)
+        let ctx = LintContext::new("[](https://example.com)", crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
-        assert!(result[0].fix.is_some(), "Empty text with URL should be fixable");
-        let fix = result[0].fix.as_ref().unwrap();
-        assert_eq!(fix.replacement, "[Link text](https://example.com)");
+        assert!(result.is_empty(), "Empty text with URL should NOT be flagged");
 
-        // Case 2: Non-URL text, empty URL - NOT fixable (can't guess the URL)
-        let ctx = LintContext::new("[text]()", crate::config::MarkdownFlavor::Standard);
+        // Case 2: Non-URL text, empty URL - flagged, NOT fixable (can't guess the URL)
+        let ctx = LintContext::new("[text]()", crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Empty URL should be flagged");
         assert!(
             result[0].fix.is_none(),
             "Non-URL text with empty URL should NOT be fixable"
         );
 
-        // Case 3: URL text, empty URL - fixable (use text as URL)
-        let ctx = LintContext::new("[https://example.com]()", crate::config::MarkdownFlavor::Standard);
+        // Case 3: URL text, empty URL - flagged, fixable (use text as URL)
+        let ctx = LintContext::new("[https://example.com]()", crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Empty URL should be flagged");
         assert!(result[0].fix.is_some(), "URL text with empty URL should be fixable");
         let fix = result[0].fix.as_ref().unwrap();
         assert_eq!(fix.replacement, "[https://example.com](https://example.com)");
 
-        // Case 4: Both empty - NOT fixable (can't guess either)
-        let ctx = LintContext::new("[]()", crate::config::MarkdownFlavor::Standard);
+        // Case 4: Both empty - flagged, NOT fixable (can't guess either)
+        let ctx = LintContext::new("[]()", crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
+        assert_eq!(result.len(), 1, "Empty URL should be flagged");
         assert!(result[0].fix.is_none(), "Both empty should NOT be fixable");
     }
 
     #[test]
     fn test_complex_markdown_document() {
+        // MD042 only flags empty URLs - not empty text
         let content = r#"# Document with various links
 
 [Valid link](https://example.com) followed by [](empty.com).
@@ -671,21 +755,16 @@ Code block should be ignored:
 [ref2]: https://ref2.com
 "#;
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
 
-        // Count the empty links
-        let empty_link_lines = [3, 7, 8, 10, 18];
-        assert_eq!(result.len(), empty_link_lines.len(), "Should find all empty links");
-
-        // Verify line numbers
-        for (i, &expected_line) in empty_link_lines.iter().enumerate() {
-            assert_eq!(
-                result[i].line, expected_line,
-                "Empty link {i} should be on line {expected_line}"
-            );
-        }
+        // Only [inline empty]() on line 9 has empty URL - should be the only one flagged
+        // All [](url) patterns have URLs so they're NOT flagged
+        // [][ref2] has a valid reference so it's NOT flagged
+        assert_eq!(result.len(), 1, "Should only flag empty URL links. Got: {result:?}");
+        assert_eq!(result[0].line, 8, "Only [inline empty]() should be flagged");
+        assert!(result[0].message.contains("[inline empty]()"));
     }
 
     #[test]
@@ -713,7 +792,7 @@ UnboundLocalError: cannot access local variable 'calls' where it is not associat
 [local scope]: https://www.pythonmorsels.com/local-and-global-variables/
 [global scope]: https://www.pythonmorsels.com/assigning-global-variables/"#;
 
-        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
 
@@ -730,6 +809,7 @@ UnboundLocalError: cannot access local variable 'calls' where it is not associat
         let ctx = LintContext::new(
             "[`#[derive(Serialize, Deserialize)`](https://serde.rs/derive.html)",
             crate::config::MarkdownFlavor::Standard,
+            None,
         );
         let rule = MD042NoEmptyLinks::new();
         let result = rule.check(&ctx).unwrap();
@@ -745,7 +825,7 @@ UnboundLocalError: cannot access local variable 'calls' where it is not associat
         let rule = MD042NoEmptyLinks::new();
 
         // Module.Class pattern with backticks
-        let ctx = LintContext::new("[`module.Class`][]", crate::config::MarkdownFlavor::MkDocs);
+        let ctx = LintContext::new("[`module.Class`][]", crate::config::MarkdownFlavor::MkDocs, None);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -753,7 +833,7 @@ UnboundLocalError: cannot access local variable 'calls' where it is not associat
         );
 
         // Reference with explicit ID
-        let ctx = LintContext::new("[`module.Class`][ref]", crate::config::MarkdownFlavor::MkDocs);
+        let ctx = LintContext::new("[`module.Class`][ref]", crate::config::MarkdownFlavor::MkDocs, None);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
@@ -761,24 +841,24 @@ UnboundLocalError: cannot access local variable 'calls' where it is not associat
         );
 
         // Path-like reference with backticks
-        let ctx = LintContext::new("[`api/endpoint`][]", crate::config::MarkdownFlavor::MkDocs);
+        let ctx = LintContext::new("[`api/endpoint`][]", crate::config::MarkdownFlavor::MkDocs, None);
         let result = rule.check(&ctx).unwrap();
         assert!(
             result.is_empty(),
             "Should not flag [`api/endpoint`][] as empty in MkDocs mode (issue #97). Got: {result:?}"
         );
 
-        // Should still flag in standard mode
-        let ctx = LintContext::new("[`module.Class`][]", crate::config::MarkdownFlavor::Standard);
+        // In standard mode, undefined collapsed references are handled by MD052, not MD042
+        // MD042 only flags truly empty links, not undefined references
+        let ctx = LintContext::new("[`module.Class`][]", crate::config::MarkdownFlavor::Standard, None);
         let result = rule.check(&ctx).unwrap();
-        assert_eq!(
-            result.len(),
-            1,
-            "Should flag [`module.Class`][] as empty in Standard mode (no auto-refs). Got: {result:?}"
+        assert!(
+            result.is_empty(),
+            "MD042 should NOT flag [`module.Class`][] - undefined refs are MD052's job. Got: {result:?}"
         );
 
         // Should still flag truly empty links even in MkDocs mode
-        let ctx = LintContext::new("[][]", crate::config::MarkdownFlavor::MkDocs);
+        let ctx = LintContext::new("[][]", crate::config::MarkdownFlavor::MkDocs, None);
         let result = rule.check(&ctx).unwrap();
         assert_eq!(
             result.len(),
