@@ -100,8 +100,9 @@ impl MD055TablePipeStyle {
         let mut leading_only_count = 0;
         let mut trailing_only_count = 0;
 
-        // Count style of header row
-        if let Some(style) = TableUtils::determine_pipe_style(lines[table_block.header_line]) {
+        // Count style of header row (table line index 0)
+        let header_content = TableUtils::extract_table_row_content(lines[table_block.header_line], table_block, 0);
+        if let Some(style) = TableUtils::determine_pipe_style(header_content) {
             match style {
                 "leading_and_trailing" => leading_and_trailing_count += 1,
                 "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
@@ -111,9 +112,10 @@ impl MD055TablePipeStyle {
             }
         }
 
-        // Count style of content rows
-        for &line_idx in &table_block.content_lines {
-            if let Some(style) = TableUtils::determine_pipe_style(lines[line_idx]) {
+        // Count style of content rows (table line indices 2, 3, 4, ...)
+        for (i, &line_idx) in table_block.content_lines.iter().enumerate() {
+            let content = TableUtils::extract_table_row_content(lines[line_idx], table_block, 2 + i);
+            if let Some(style) = TableUtils::determine_pipe_style(content) {
                 match style {
                     "leading_and_trailing" => leading_and_trailing_count += 1,
                     "no_leading_or_trailing" => no_leading_or_trailing_count += 1,
@@ -148,12 +150,72 @@ impl MD055TablePipeStyle {
         }
     }
 
-    /// Fix a table row to match the target style
-    /// Uses surgical fixes: only adds/removes pipes, preserves all user formatting
+    /// Simple table row fix for tests - creates a dummy TableBlock without list context
+    #[cfg(test)]
     fn fix_table_row(&self, line: &str, target_style: &str) -> String {
-        let trimmed = line.trim();
+        let dummy_block = TableBlock {
+            start_line: 0,
+            end_line: 0,
+            header_line: 0,
+            delimiter_line: 0,
+            content_lines: vec![],
+            list_context: None,
+        };
+        self.fix_table_row_with_context(line, target_style, &dummy_block, 0)
+    }
+
+    /// Fix a table row to match the target style, with full context for list tables
+    ///
+    /// This handles tables inside list items by stripping the list prefix,
+    /// fixing the table content, then restoring the appropriate prefix.
+    fn fix_table_row_with_context(
+        &self,
+        line: &str,
+        target_style: &str,
+        table_block: &TableBlock,
+        table_line_index: usize,
+    ) -> String {
+        // Extract blockquote prefix first
+        let (bq_prefix, after_bq) = TableUtils::extract_blockquote_prefix(line);
+
+        // Handle list context if present
+        if let Some(ref list_ctx) = table_block.list_context {
+            if table_line_index == 0 {
+                // Header line: extract list prefix
+                let (list_prefix, content, _) = TableUtils::extract_list_prefix(after_bq);
+                let fixed_content = self.fix_table_content(content.trim(), target_style);
+
+                // Restore prefixes: blockquote + list prefix + fixed content
+                if bq_prefix.is_empty() && list_prefix.is_empty() {
+                    fixed_content
+                } else {
+                    format!("{bq_prefix}{list_prefix}{fixed_content}")
+                }
+            } else {
+                // Continuation lines: strip indentation, then restore it
+                let content_indent = list_ctx.content_indent;
+                let stripped = TableUtils::extract_table_row_content(line, table_block, table_line_index);
+                let fixed_content = self.fix_table_content(stripped.trim(), target_style);
+
+                // Restore prefixes: blockquote + indentation + fixed content
+                let indent = " ".repeat(content_indent);
+                format!("{bq_prefix}{indent}{fixed_content}")
+            }
+        } else {
+            // No list context, just handle blockquote prefix
+            let fixed_content = self.fix_table_content(after_bq.trim(), target_style);
+            if bq_prefix.is_empty() {
+                fixed_content
+            } else {
+                format!("{bq_prefix}{fixed_content}")
+            }
+        }
+    }
+
+    /// Fix the table content (without any prefix handling)
+    fn fix_table_content(&self, trimmed: &str, target_style: &str) -> String {
         if !trimmed.contains('|') {
-            return line.to_string();
+            return trimmed.to_string();
         }
 
         let has_leading = trimmed.starts_with('|');
@@ -224,7 +286,7 @@ impl MD055TablePipeStyle {
 
                 result
             }
-            _ => line.to_string(),
+            _ => trimmed.to_string(),
         }
     }
 }
@@ -294,11 +356,11 @@ impl Rule for MD055TablePipeStyle {
             let table_start_line = table_block.start_line + 1; // Convert to 1-indexed
             let table_end_line = table_block.end_line + 1; // Convert to 1-indexed
 
-            // Build the complete fixed table content
+            // Build the complete fixed table content with proper table line indices
             let mut fixed_table_lines: Vec<String> = Vec::with_capacity(all_line_indices.len());
-            for &line_idx in &all_line_indices {
+            for (table_line_idx, &line_idx) in all_line_indices.iter().enumerate() {
                 let line = lines[line_idx];
-                let fixed_line = self.fix_table_row(line, target_style);
+                let fixed_line = self.fix_table_row_with_context(line, target_style, table_block, table_line_idx);
                 if line_idx < lines.len() - 1 {
                     fixed_table_lines.push(format!("{fixed_line}\n"));
                 } else {
@@ -309,9 +371,11 @@ impl Rule for MD055TablePipeStyle {
             let table_range = line_index.multi_line_range(table_start_line, table_end_line);
 
             // Check all rows in the table
-            for &line_idx in &all_line_indices {
+            for (table_line_idx, &line_idx) in all_line_indices.iter().enumerate() {
                 let line = lines[line_idx];
-                if let Some(current_style) = TableUtils::determine_pipe_style(line) {
+                // Extract content to properly check pipe style (handles list/blockquote prefixes)
+                let content = TableUtils::extract_table_row_content(line, table_block, table_line_idx);
+                if let Some(current_style) = TableUtils::determine_pipe_style(content) {
                     // Only flag lines with actual style mismatches
                     let needs_fixing = current_style != target_style;
 
@@ -390,14 +454,15 @@ impl Rule for MD055TablePipeStyle {
                 configured_style
             };
 
-            // Fix all rows in the table
-            let all_lines = std::iter::once(table_block.header_line)
+            // Fix all rows in the table with proper table line indices
+            let all_line_indices: Vec<usize> = std::iter::once(table_block.header_line)
                 .chain(std::iter::once(table_block.delimiter_line))
-                .chain(table_block.content_lines.iter().copied());
+                .chain(table_block.content_lines.iter().copied())
+                .collect();
 
-            for line_idx in all_lines {
+            for (table_line_idx, &line_idx) in all_line_indices.iter().enumerate() {
                 let line = lines[line_idx];
-                let fixed_line = self.fix_table_row(line, target_style);
+                let fixed_line = self.fix_table_row_with_context(line, target_style, table_block, table_line_idx);
                 result_lines[line_idx] = fixed_line;
             }
         }
@@ -571,4 +636,94 @@ mod tests {
         // Should not panic and should handle gracefully
         assert!(!result.is_empty());
     }
+
+    // === Issue #305: Blockquote table tests ===
+
+    #[test]
+    fn test_fix_table_row_in_blockquote() {
+        let rule = MD055TablePipeStyle::new("leading_and_trailing".to_string());
+
+        // Blockquote table without leading pipe
+        let result = rule.fix_table_row("> H1 | H2", "leading_and_trailing");
+        assert_eq!(result, "> | H1 | H2 |");
+
+        // Blockquote table that already has pipes
+        let result = rule.fix_table_row("> | H1 | H2 |", "leading_and_trailing");
+        assert_eq!(result, "> | H1 | H2 |");
+
+        // Removing pipes from blockquote table
+        let result = rule.fix_table_row("> | H1 | H2 |", "no_leading_or_trailing");
+        assert_eq!(result, "> H1 | H2");
+    }
+
+    #[test]
+    fn test_fix_table_row_in_nested_blockquote() {
+        let rule = MD055TablePipeStyle::new("leading_and_trailing".to_string());
+
+        // Double-nested blockquote
+        let result = rule.fix_table_row(">> H1 | H2", "leading_and_trailing");
+        assert_eq!(result, ">> | H1 | H2 |");
+
+        // Triple-nested blockquote
+        let result = rule.fix_table_row(">>> H1 | H2", "leading_and_trailing");
+        assert_eq!(result, ">>> | H1 | H2 |");
+    }
+
+    #[test]
+    fn test_blockquote_table_full_document() {
+        let rule = MD055TablePipeStyle::new("leading_and_trailing".to_string());
+
+        // Full table in blockquote (2 columns, matching delimiter)
+        let content = "> H1 | H2\n> ----|----\n> a  | b";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.fix(&ctx).unwrap();
+
+        // Each line should have the blockquote prefix preserved and pipes added
+        // The leading_and_trailing style adds "| " after blockquote prefix
+        assert!(
+            result.starts_with("> |"),
+            "Header should start with blockquote + pipe. Got:\n{result}"
+        );
+        // Delimiter row gets leading pipe added, so check for "> | ---" pattern
+        assert!(
+            result.contains("> | ----"),
+            "Delimiter should have blockquote prefix + leading pipe. Got:\n{result}"
+        );
+    }
+
+    #[test]
+    fn test_blockquote_table_no_leading_trailing() {
+        let rule = MD055TablePipeStyle::new("no_leading_or_trailing".to_string());
+
+        // Table with pipes that should be removed
+        let content = "> | H1 | H2 |\n> |----|----|---|\n> | a  | b |";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.fix(&ctx).unwrap();
+
+        // Pipes should be removed but blockquote prefix preserved
+        let lines: Vec<&str> = result.lines().collect();
+        assert!(lines[0].starts_with("> "), "Line should start with blockquote prefix");
+        assert!(
+            !lines[0].starts_with("> |"),
+            "Leading pipe should be removed. Got: {}",
+            lines[0]
+        );
+    }
+
+    #[test]
+    fn test_mixed_regular_and_blockquote_tables() {
+        let rule = MD055TablePipeStyle::new("leading_and_trailing".to_string());
+
+        // Document with both regular and blockquote tables
+        let content = "H1 | H2\n---|---\na | b\n\n> H3 | H4\n> ---|---\n> c | d";
+        let ctx = crate::lint_context::LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let result = rule.fix(&ctx).unwrap();
+
+        // Both tables should be fixed
+        assert!(result.contains("| H1 | H2 |"), "Regular table should have pipes added");
+        assert!(
+            result.contains("> | H3 | H4 |"),
+            "Blockquote table should have pipes added with prefix preserved"
+        );
+    }
 }
