@@ -6,6 +6,7 @@ use unicode_width::UnicodeWidthStr;
 
 mod md060_config;
 use crate::md013_line_length::MD013Config;
+pub use md060_config::ColumnAlign;
 use md060_config::MD060Config;
 
 #[derive(Debug, Clone, Copy, PartialEq)]
@@ -159,6 +160,7 @@ impl MD060TableFormat {
                 enabled,
                 style,
                 max_width: LineLength::from_const(0),
+                column_align: ColumnAlign::Auto,
             },
             md013_config: MD013Config::default(),
             md013_disabled: false,
@@ -331,6 +333,7 @@ impl MD060TableFormat {
         column_alignments: &[ColumnAlignment],
         is_delimiter: bool,
         compact_delimiter: bool,
+        column_align_override: ColumnAlign,
     ) -> String {
         let formatted_cells: Vec<String> = cells
             .iter()
@@ -376,8 +379,13 @@ impl MD060TableFormat {
                     let current_width = Self::calculate_cell_display_width(cell);
                     let padding = target_width.saturating_sub(current_width);
 
-                    // Apply alignment based on column's alignment indicator
-                    let alignment = column_alignments.get(i).copied().unwrap_or(ColumnAlignment::Left);
+                    // Apply alignment: use override if specified, otherwise use delimiter indicators
+                    let alignment = match column_align_override {
+                        ColumnAlign::Auto => column_alignments.get(i).copied().unwrap_or(ColumnAlignment::Left),
+                        ColumnAlign::Left => ColumnAlignment::Left,
+                        ColumnAlign::Center => ColumnAlignment::Center,
+                        ColumnAlign::Right => ColumnAlignment::Right,
+                    };
                     match alignment {
                         ColumnAlignment::Left => {
                             // Left: content on left, padding on right
@@ -411,13 +419,22 @@ impl MD060TableFormat {
         format!("|{}|", formatted_cells.join("|"))
     }
 
-    /// Checks if a table is already aligned with consistent column widths.
+    /// Checks if a table is already aligned with consistent column widths
+    /// and the delimiter row style matches the target style.
     ///
     /// A table is considered "already aligned" if:
     /// 1. All rows have the same display length
     /// 2. Each column has consistent cell width across all rows
     /// 3. The delimiter row has valid minimum widths (at least 3 chars per cell)
-    fn is_table_already_aligned(table_lines: &[&str], flavor: crate::config::MarkdownFlavor) -> bool {
+    /// 4. The delimiter row style matches the target style (compact_delimiter parameter)
+    ///
+    /// The `compact_delimiter` parameter indicates whether the target style is "aligned-no-space"
+    /// (true = no spaces around dashes, false = spaces around dashes).
+    fn is_table_already_aligned(
+        table_lines: &[&str],
+        flavor: crate::config::MarkdownFlavor,
+        compact_delimiter: bool,
+    ) -> bool {
         if table_lines.len() < 2 {
             return false;
         }
@@ -457,9 +474,27 @@ impl MD060TableFormat {
                     return false;
                 }
             }
+
+            // Check if delimiter row style matches the target style
+            // compact_delimiter=true means "aligned-no-space" (no spaces around dashes)
+            // compact_delimiter=false means "aligned" (spaces around dashes)
+            let delimiter_has_spaces = delimiter_row
+                .iter()
+                .all(|cell| cell.starts_with(' ') && cell.ends_with(' '));
+
+            // If target is compact (no spaces) but current has spaces, not aligned
+            // If target is spaced but current has no spaces, not aligned
+            if compact_delimiter && delimiter_has_spaces {
+                return false;
+            }
+            if !compact_delimiter && !delimiter_has_spaces {
+                return false;
+            }
         }
 
         // Check each column has consistent width across all content rows
+        // Use cell.width() to get display width INCLUDING padding, not trimmed content
+        // This correctly handles CJK characters (display width 2, byte length 3)
         for col_idx in 0..num_columns {
             let mut widths = Vec::new();
             for (row_idx, row) in parsed.iter().enumerate() {
@@ -468,10 +503,10 @@ impl MD060TableFormat {
                     continue;
                 }
                 if let Some(cell) = row.get(col_idx) {
-                    widths.push(cell.len());
+                    widths.push(cell.width());
                 }
             }
-            // All content cells in this column should have the same raw width
+            // All content cells in this column should have the same display width
             if !widths.is_empty() && !widths.iter().all(|&w| w == widths[0]) {
                 return false;
             }
@@ -564,10 +599,34 @@ impl MD060TableFormat {
         // All lines in the same table should have the same blockquote level
         let (blockquote_prefix, _) = Self::extract_blockquote_prefix(table_lines[0]);
 
-        // Strip blockquote prefix from all lines for processing
+        // Extract list prefix if present (for tables inside list items)
+        let list_context = &table_block.list_context;
+        let (list_prefix, continuation_indent) = if let Some(ctx) = list_context {
+            (ctx.list_prefix.as_str(), " ".repeat(ctx.content_indent))
+        } else {
+            ("", String::new())
+        };
+
+        // Strip blockquote prefix and list prefix from all lines for processing
         let stripped_lines: Vec<&str> = table_lines
             .iter()
-            .map(|line| Self::extract_blockquote_prefix(line).1)
+            .enumerate()
+            .map(|(i, line)| {
+                let after_blockquote = Self::extract_blockquote_prefix(line).1;
+                if list_context.is_some() {
+                    if i == 0 {
+                        // Header line: strip list prefix
+                        crate::utils::table_utils::TableUtils::extract_list_prefix(after_blockquote).1
+                    } else {
+                        // Continuation lines: strip expected indentation
+                        after_blockquote
+                            .strip_prefix(&continuation_indent)
+                            .unwrap_or(after_blockquote.trim_start())
+                    }
+                } else {
+                    after_blockquote
+                }
+            })
             .collect();
 
         let style = self.config.style.as_str();
@@ -603,6 +662,7 @@ impl MD060TableFormat {
                                 &column_alignments,
                                 is_delimiter,
                                 false,
+                                self.config.column_align,
                             ));
                         }
                     }
@@ -623,9 +683,13 @@ impl MD060TableFormat {
             "aligned" | "aligned-no-space" => {
                 let compact_delimiter = style == "aligned-no-space";
 
-                // If the table is already aligned with consistent column widths,
-                // preserve it as-is rather than forcing our preferred minimum widths
-                if Self::is_table_already_aligned(&stripped_lines, flavor) {
+                // If the table is already aligned with consistent column widths
+                // AND the delimiter style matches the target style, preserve as-is
+                // EXCEPT: when column-align is explicitly set (not Auto), we must reformat
+                // to apply the specified text alignment within cells
+                if self.config.column_align == ColumnAlign::Auto
+                    && Self::is_table_already_aligned(&stripped_lines, flavor, compact_delimiter)
+                {
                     return TableFormatResult {
                         lines: table_lines.iter().map(|s| s.to_string()).collect(),
                         auto_compacted: false,
@@ -661,6 +725,7 @@ impl MD060TableFormat {
                             &column_alignments,
                             is_delimiter,
                             compact_delimiter,
+                            self.config.column_align,
                         ));
                     }
                 }
@@ -674,10 +739,23 @@ impl MD060TableFormat {
             }
         }
 
-        // Re-add blockquote prefix to all formatted lines
+        // Re-add blockquote prefix and list prefix to all formatted lines
         let prefixed_result: Vec<String> = result
             .into_iter()
-            .map(|line| format!("{blockquote_prefix}{line}"))
+            .enumerate()
+            .map(|(i, line)| {
+                if list_context.is_some() {
+                    if i == 0 {
+                        // Header line: add list prefix
+                        format!("{blockquote_prefix}{list_prefix}{line}")
+                    } else {
+                        // Continuation lines: add indentation
+                        format!("{blockquote_prefix}{continuation_indent}{line}")
+                    }
+                } else {
+                    format!("{blockquote_prefix}{line}")
+                }
+            })
             .collect();
 
         TableFormatResult {
@@ -1040,6 +1118,7 @@ mod tests {
             enabled: true,
             style: "aligned-no-space".to_string(),
             max_width: LineLength::from_const(50),
+            column_align: ColumnAlign::Auto,
         };
         let rule = MD060TableFormat::from_config_struct(config, md013_with_line_length(80), false);
 
@@ -1186,6 +1265,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
         };
         let rule = MD060TableFormat::from_config_struct(config, md013_with_line_length(80), false);
 
@@ -1215,6 +1295,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(50),
+            column_align: ColumnAlign::Auto,
         };
         let rule = MD060TableFormat::from_config_struct(config, md013_with_line_length(80), false); // MD013 setting doesn't matter
 
@@ -1245,6 +1326,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(100),
+            column_align: ColumnAlign::Auto,
         };
         let rule = MD060TableFormat::from_config_struct(config, md013_with_line_length(80), false);
 
@@ -1270,6 +1352,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
         };
         let rule = MD060TableFormat::from_config_struct(config, md013_with_line_length(30), false);
 
@@ -1292,6 +1375,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(24),
+            column_align: ColumnAlign::Auto,
         };
         let rule_tight = MD060TableFormat::from_config_struct(config_tight, md013_with_line_length(80), false);
 
@@ -1308,6 +1392,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
         };
         let rule = MD060TableFormat::from_config_struct(config, md013_with_line_length(80), false);
 
@@ -1331,6 +1416,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(0), // Inherit
+            column_align: ColumnAlign::Auto,
         };
 
         // Test with different MD013 line_length values
@@ -1362,6 +1448,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(17),
+            column_align: ColumnAlign::Auto,
         };
         let rule = MD060TableFormat::from_config_struct(config, md013_with_line_length(80), false);
 
@@ -1381,6 +1468,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(16),
+            column_align: ColumnAlign::Auto,
         };
         let rule_under = MD060TableFormat::from_config_struct(config_under, md013_with_line_length(80), false);
 
@@ -1398,6 +1486,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(50),
+            column_align: ColumnAlign::Auto,
         };
         let rule = MD060TableFormat::from_config_struct(config, md013_with_line_length(80), false);
 
@@ -1465,6 +1554,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(100), // Large enough to not trigger auto-compact
+            column_align: ColumnAlign::Auto,
         };
         let rule = MD060TableFormat::from_config_struct(config, md013_with_line_length(80), false);
 
@@ -1492,6 +1582,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(0), // Inherit
+            column_align: ColumnAlign::Auto,
         };
         let md013_config = MD013Config::default();
         let rule = MD060TableFormat::from_config_struct(config, md013_config, true /* disabled */);
@@ -1518,6 +1609,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
         };
         let md013_config = MD013Config {
             tables: false, // User doesn't care about table line length
@@ -1547,6 +1639,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
         };
         let md013_config = MD013Config {
             tables: true,
@@ -1576,6 +1669,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(50), // Explicit limit
+            column_align: ColumnAlign::Auto,
         };
         let md013_config = MD013Config {
             tables: false,                          // This would make it unlimited...
@@ -1603,6 +1697,7 @@ mod tests {
             enabled: true,
             style: "aligned".to_string(),
             max_width: LineLength::from_const(0), // Inherit
+            column_align: ColumnAlign::Auto,
         };
         let md013_config = MD013Config {
             tables: true,
@@ -1622,4 +1717,510 @@ mod tests {
             "Should be compact format when inheriting MD013 limit"
         );
     }
+
+    // === Issue #311: aligned-no-space style tests ===
+
+    #[test]
+    fn test_aligned_no_space_reformats_spaced_delimiter() {
+        // Table with "aligned" style (spaces around dashes) should be reformatted
+        // when target style is "aligned-no-space"
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned-no-space".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        // Input: aligned table with spaces around dashes
+        let content = "| Header 1 | Header 2 |\n| -------- | -------- |\n| Cell 1   | Cell 2   |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Should have no spaces around dashes in delimiter row
+        // The dashes may be longer to match column width, but should have no spaces
+        assert!(
+            !fixed.contains("| ----"),
+            "Delimiter should NOT have spaces after pipe. Got:\n{fixed}"
+        );
+        assert!(
+            !fixed.contains("---- |"),
+            "Delimiter should NOT have spaces before pipe. Got:\n{fixed}"
+        );
+        // Verify it has the compact delimiter format (dashes touching pipes)
+        assert!(
+            fixed.contains("|----"),
+            "Delimiter should have dashes touching the leading pipe. Got:\n{fixed}"
+        );
+    }
+
+    #[test]
+    fn test_aligned_reformats_compact_delimiter() {
+        // Table with "aligned-no-space" style (no spaces around dashes) should be reformatted
+        // when target style is "aligned"
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        // Input: aligned-no-space table (no spaces around dashes)
+        let content = "| Header 1 | Header 2 |\n|----------|----------|\n| Cell 1   | Cell 2   |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Should have spaces around dashes in delimiter row
+        assert!(
+            fixed.contains("| -------- | -------- |") || fixed.contains("| ---------- | ---------- |"),
+            "Delimiter should have spaces around dashes. Got:\n{fixed}"
+        );
+    }
+
+    #[test]
+    fn test_aligned_no_space_preserves_matching_table() {
+        // Table already in "aligned-no-space" style should be preserved
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned-no-space".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        // Input: already in aligned-no-space style
+        let content = "| Header 1 | Header 2 |\n|----------|----------|\n| Cell 1   | Cell 2   |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Should be preserved as-is
+        assert_eq!(
+            fixed, content,
+            "Table already in aligned-no-space style should be preserved"
+        );
+    }
+
+    #[test]
+    fn test_aligned_preserves_matching_table() {
+        // Table already in "aligned" style should be preserved
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        // Input: already in aligned style
+        let content = "| Header 1 | Header 2 |\n| -------- | -------- |\n| Cell 1   | Cell 2   |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Should be preserved as-is
+        assert_eq!(fixed, content, "Table already in aligned style should be preserved");
+    }
+
+    #[test]
+    fn test_cjk_table_display_width_consistency() {
+        // Test that is_table_already_aligned correctly uses display width, not byte length
+        // CJK characters have display width of 2, but byte length of 3 in UTF-8
+        //
+        // This table is NOT aligned because line lengths differ
+        // (CJK chars take 3 bytes in UTF-8 but only 2 columns in display)
+        let table_lines = vec!["| 名前 | Age |", "|------|-----|", "| 田中 | 25  |"];
+
+        // First check is raw line length equality (byte-based), which fails
+        let is_aligned =
+            MD060TableFormat::is_table_already_aligned(&table_lines, crate::config::MarkdownFlavor::Standard, false);
+        assert!(
+            !is_aligned,
+            "Table with uneven raw line lengths should NOT be considered aligned"
+        );
+    }
+
+    #[test]
+    fn test_cjk_width_calculation_in_aligned_check() {
+        // calculate_cell_display_width trims content before calculating width
+        // Verify CJK width is correctly calculated (2 per character)
+        let cjk_width = MD060TableFormat::calculate_cell_display_width("名前");
+        assert_eq!(cjk_width, 4, "Two CJK characters should have display width 4");
+
+        let ascii_width = MD060TableFormat::calculate_cell_display_width("Age");
+        assert_eq!(ascii_width, 3, "Three ASCII characters should have display width 3");
+
+        // Test that spacing is trimmed before width calculation
+        let padded_cjk = MD060TableFormat::calculate_cell_display_width(" 名前 ");
+        assert_eq!(padded_cjk, 4, "Padded CJK should have same width after trim");
+
+        // Test mixed content
+        let mixed = MD060TableFormat::calculate_cell_display_width(" 日本語ABC ");
+        // 3 CJK chars (width 6) + 3 ASCII (width 3) = 9
+        assert_eq!(mixed, 9, "Mixed CJK/ASCII content");
+    }
+
+    // === Issue #317: column-align option tests ===
+
+    #[test]
+    fn test_md060_column_align_left() {
+        // Default/explicit left alignment
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Left,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        let content = "| Name | Age | City |\n|---|---|---|\n| Alice | 30 | Seattle |\n| Bob | 25 | Portland |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+        let lines: Vec<&str> = fixed.lines().collect();
+
+        // Left aligned: content on left, padding on right
+        assert!(
+            lines[2].contains("| Alice "),
+            "Content should be left-aligned (Alice should have trailing padding)"
+        );
+        assert!(
+            lines[3].contains("| Bob   "),
+            "Content should be left-aligned (Bob should have trailing padding)"
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_center() {
+        // Center alignment forces all columns to center
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Center,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        let content = "| Name | Age | City |\n|---|---|---|\n| Alice | 30 | Seattle |\n| Bob | 25 | Portland |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+        let lines: Vec<&str> = fixed.lines().collect();
+
+        // Center aligned: padding split on both sides
+        // "Bob" (3 chars) in "Name" column (5 chars) = 2 padding total, 1 left, 1 right
+        assert!(
+            lines[3].contains("|  Bob  |"),
+            "Bob should be centered with padding on both sides. Got: {}",
+            lines[3]
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_right() {
+        // Right alignment forces all columns to right-align
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Right,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        let content = "| Name | Age | City |\n|---|---|---|\n| Alice | 30 | Seattle |\n| Bob | 25 | Portland |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+        let lines: Vec<&str> = fixed.lines().collect();
+
+        // Right aligned: padding on left, content on right
+        assert!(
+            lines[3].contains("|   Bob |"),
+            "Bob should be right-aligned with padding on left. Got: {}",
+            lines[3]
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_auto_respects_delimiter() {
+        // Auto mode (default) should respect delimiter row alignment indicators
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        // Left, center, right columns via delimiter indicators
+        let content = "| Left | Center | Right |\n|:---|:---:|---:|\n| A | B | C |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Verify alignment is applied per-column based on delimiter
+        assert!(fixed.contains("| A "), "Left column should be left-aligned");
+        // Center and right columns with longer content in header
+        let lines: Vec<&str> = fixed.lines().collect();
+        // The content row should have B centered and C right-aligned
+        // B (1 char) in "Center" (6 chars) = 5 padding, ~2 left, ~3 right
+        // C (1 char) in "Right" (5 chars) = 4 padding, all on left
+        assert!(
+            lines[2].contains(" C |"),
+            "Right column should be right-aligned. Got: {}",
+            lines[2]
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_overrides_delimiter_indicators() {
+        // column-align should override delimiter row indicators
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Right, // Override all to right
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        // Delimiter says left, center, right - but we override all to right
+        let content = "| Left | Center | Right |\n|:---|:---:|---:|\n| A | B | C |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+        let lines: Vec<&str> = fixed.lines().collect();
+
+        // ALL columns should be right-aligned despite delimiter indicators
+        // "A" in "Left" column (4 chars minimum due to header length) should be right-aligned
+        assert!(
+            lines[2].contains("    A |") || lines[2].contains("   A |"),
+            "Even left-indicated column should be right-aligned. Got: {}",
+            lines[2]
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_with_aligned_no_space() {
+        // column-align should work with aligned-no-space style
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned-no-space".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Center,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        let content = "| Name | Age |\n|---|---|\n| Alice | 30 |\n| Bob | 25 |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+        let lines: Vec<&str> = fixed.lines().collect();
+
+        // Delimiter row should have no spaces (aligned-no-space)
+        assert!(
+            lines[1].contains("|---"),
+            "Delimiter should have no spaces in aligned-no-space style. Got: {}",
+            lines[1]
+        );
+        // Content should still be centered
+        assert!(
+            lines[3].contains("|  Bob  |"),
+            "Content should be centered. Got: {}",
+            lines[3]
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_config_parsing() {
+        // Test that column-align config is correctly parsed
+        let toml_str = r#"
+enabled = true
+style = "aligned"
+column-align = "center"
+"#;
+        let config: MD060Config = toml::from_str(toml_str).expect("Should parse config");
+        assert_eq!(config.column_align, ColumnAlign::Center);
+
+        let toml_str = r#"
+enabled = true
+style = "aligned"
+column-align = "right"
+"#;
+        let config: MD060Config = toml::from_str(toml_str).expect("Should parse config");
+        assert_eq!(config.column_align, ColumnAlign::Right);
+
+        let toml_str = r#"
+enabled = true
+style = "aligned"
+column-align = "left"
+"#;
+        let config: MD060Config = toml::from_str(toml_str).expect("Should parse config");
+        assert_eq!(config.column_align, ColumnAlign::Left);
+
+        let toml_str = r#"
+enabled = true
+style = "aligned"
+column-align = "auto"
+"#;
+        let config: MD060Config = toml::from_str(toml_str).expect("Should parse config");
+        assert_eq!(config.column_align, ColumnAlign::Auto);
+    }
+
+    #[test]
+    fn test_md060_column_align_default_is_auto() {
+        // Without column-align specified, default should be Auto
+        let toml_str = r#"
+enabled = true
+style = "aligned"
+"#;
+        let config: MD060Config = toml::from_str(toml_str).expect("Should parse config");
+        assert_eq!(config.column_align, ColumnAlign::Auto);
+    }
+
+    #[test]
+    fn test_md060_column_align_reformats_already_aligned_table() {
+        // A table that is already aligned (left) should be reformatted when column-align=right
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Right,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        // This table is already properly aligned with left alignment
+        let content = "| Name  | Age |\n| ----- | --- |\n| Alice | 30  |\n| Bob   | 25  |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+        let lines: Vec<&str> = fixed.lines().collect();
+
+        // Should be reformatted with right alignment
+        assert!(
+            lines[2].contains("| Alice |") && lines[2].contains("|  30 |"),
+            "Already aligned table should be reformatted with right alignment. Got: {}",
+            lines[2]
+        );
+        assert!(
+            lines[3].contains("|   Bob |") || lines[3].contains("|  Bob |"),
+            "Bob should be right-aligned. Got: {}",
+            lines[3]
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_with_cjk_characters() {
+        // CJK characters have double display width - centering should account for this
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Center,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        let content = "| Name | City |\n|---|---|\n| Alice | 東京 |\n| Bob | LA |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Both Alice and Bob should be centered, and 東京 should be properly aligned
+        // considering its double-width display
+        assert!(fixed.contains("Bob"), "Table should contain Bob");
+        assert!(fixed.contains("東京"), "Table should contain 東京");
+    }
+
+    #[test]
+    fn test_md060_column_align_ignored_for_compact_style() {
+        // column-align should have no effect on compact style (minimal padding)
+        let config = MD060Config {
+            enabled: true,
+            style: "compact".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Right, // This should be ignored
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        let content = "| Name | Age |\n|---|---|\n| Alice | 30 |\n| Bob | 25 |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Compact style: single space padding, no alignment
+        assert!(
+            fixed.contains("| Alice |"),
+            "Compact style should have single space padding, not alignment. Got: {fixed}"
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_ignored_for_tight_style() {
+        // column-align should have no effect on tight style (no padding)
+        let config = MD060Config {
+            enabled: true,
+            style: "tight".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Center, // This should be ignored
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        let content = "| Name | Age |\n|---|---|\n| Alice | 30 |\n| Bob | 25 |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Tight style: no spaces at all
+        assert!(
+            fixed.contains("|Alice|"),
+            "Tight style should have no spaces. Got: {fixed}"
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_with_empty_cells() {
+        // Empty cells should be handled correctly with centering
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Center,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        let content = "| Name | Age |\n|---|---|\n| Alice | 30 |\n|  | 25 |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+        let lines: Vec<&str> = fixed.lines().collect();
+
+        // Empty cell should have all padding (centered empty string)
+        assert!(
+            lines[3].contains("|       |") || lines[3].contains("|      |"),
+            "Empty cell should be padded correctly. Got: {}",
+            lines[3]
+        );
+    }
+
+    #[test]
+    fn test_md060_column_align_auto_preserves_already_aligned() {
+        // With column-align=auto (default), already aligned tables should be preserved
+        let config = MD060Config {
+            enabled: true,
+            style: "aligned".to_string(),
+            max_width: LineLength::from_const(0),
+            column_align: ColumnAlign::Auto,
+        };
+        let rule = MD060TableFormat::from_config_struct(config, MD013Config::default(), false);
+
+        // This table is already properly aligned
+        let content = "| Name  | Age |\n| ----- | --- |\n| Alice | 30  |\n| Bob   | 25  |";
+        let ctx = LintContext::new(content, crate::config::MarkdownFlavor::Standard, None);
+
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Should be preserved as-is
+        assert_eq!(
+            fixed, content,
+            "Already aligned table should be preserved with column-align=auto"
+        );
+    }
 }
