@@ -11,6 +11,10 @@ use crate::utils::regex_cache::{
     LINKED_IMAGE_INLINE_INLINE, LINKED_IMAGE_INLINE_REF, LINKED_IMAGE_REF_INLINE, LINKED_IMAGE_REF_REF,
     REF_IMAGE_REGEX, REF_LINK_REGEX, SHORTCUT_REF_REGEX, WIKI_LINK_REGEX,
 };
+use crate::utils::sentence_utils::{
+    get_abbreviations, is_cjk_char, is_cjk_sentence_ending, is_closing_quote, is_opening_quote,
+    text_ends_with_abbreviation,
+};
 use pulldown_cmark::{Event, Options, Parser, Tag, TagEnd};
 use std::collections::HashSet;
 
@@ -43,93 +47,6 @@ impl Default for ReflowOptions {
     }
 }
 
-/// Get the effective abbreviations set based on options
-/// All abbreviations are normalized to lowercase for case-insensitive matching
-/// Custom abbreviations are always merged with built-in defaults
-fn get_abbreviations(custom: &Option<Vec<String>>) -> HashSet<String> {
-    // Only include abbreviations that:
-    // 1. Conventionally ALWAYS have a period in standard writing
-    // 2. Are followed by something (name, example), not sentence-final
-    //
-    // Do NOT include:
-    // - Words that don't typically take periods (vs, etc)
-    // - Abbreviations that can end sentences (Inc., Ph.D., U.S.)
-    let mut abbreviations: HashSet<String> = [
-        // Titles - always have period, always followed by a name
-        "Mr", "Mrs", "Ms", "Dr", "Prof", "Sr", "Jr",
-        // Latin - always written with periods, introduce examples/references
-        "i.e", "e.g",
-    ]
-    .iter()
-    .map(|s| s.to_lowercase())
-    .collect();
-
-    // Always extend defaults with custom abbreviations
-    // Strip any trailing periods and normalize to lowercase for consistent matching
-    if let Some(custom_list) = custom {
-        for abbr in custom_list {
-            let normalized = abbr.trim_end_matches('.').to_lowercase();
-            if !normalized.is_empty() {
-                abbreviations.insert(normalized);
-            }
-        }
-    }
-
-    abbreviations
-}
-
-/// Check if text ends with a common abbreviation followed by a period
-///
-/// Abbreviations only count when followed by a period, not ! or ?.
-/// This prevents false positives where words ending in abbreviation-like
-/// letter sequences (e.g., "paradigms" ending in "ms") are incorrectly
-/// detected as abbreviations.
-///
-/// Examples:
-///   - "Dr." -> true (abbreviation)
-///   - "Dr?" -> false (question, not abbreviation)
-///   - "paradigms." -> false (not in abbreviation list)
-///   - "paradigms?" -> false (question mark, not abbreviation)
-///
-/// See: Issue #150
-fn text_ends_with_abbreviation(text: &str, abbreviations: &HashSet<String>) -> bool {
-    // Only check if text ends with a period (abbreviations require periods)
-    if !text.ends_with('.') {
-        return false;
-    }
-
-    // Remove the trailing period
-    let without_period = text.trim_end_matches('.');
-
-    // Get the last word by splitting on whitespace
-    let last_word = without_period.split_whitespace().last().unwrap_or("");
-
-    if last_word.is_empty() {
-        return false;
-    }
-
-    // O(1) HashSet lookup (abbreviations are already lowercase)
-    abbreviations.contains(&last_word.to_lowercase())
-}
-
-/// Check if a character is CJK sentence-ending punctuation
-/// These include: 。(ideographic full stop), ！(fullwidth exclamation), ？(fullwidth question)
-fn is_cjk_sentence_ending(c: char) -> bool {
-    matches!(c, '。' | '！' | '？')
-}
-
-/// Check if a character is a CJK character (Chinese, Japanese, Korean)
-fn is_cjk_char(c: char) -> bool {
-    // CJK Unified Ideographs and common extensions
-    matches!(c,
-        '\u{4E00}'..='\u{9FFF}' |   // CJK Unified Ideographs
-        '\u{3400}'..='\u{4DBF}' |   // CJK Unified Ideographs Extension A
-        '\u{3040}'..='\u{309F}' |   // Hiragana
-        '\u{30A0}'..='\u{30FF}' |   // Katakana
-        '\u{AC00}'..='\u{D7AF}'     // Hangul Syllables
-    )
-}
-
 /// Detect if a character position is a sentence boundary
 /// Based on the approach from github.com/JoshuaKGoldberg/sentences-per-line
 /// Supports both ASCII punctuation (. ! ?) and CJK punctuation (。 ！ ？)
@@ -185,10 +102,28 @@ fn is_sentence_boundary(text: &str, pos: usize, abbreviations: &HashSet<String>)
         return false;
     }
 
-    // Must be followed by space, or by emphasis/strikethrough marker followed by space
+    // Must be followed by space, closing quote, or emphasis/strikethrough marker followed by space
     let (_space_pos, after_space_pos) = if next_char == ' ' {
         // Normal case: punctuation followed by space
         (pos + 1, pos + 2)
+    } else if is_closing_quote(next_char) && pos + 2 < chars.len() {
+        // Sentence ends with quote - check what follows the quote
+        if chars[pos + 2] == ' ' {
+            // Just quote followed by space: 'sentence." '
+            (pos + 2, pos + 3)
+        } else if (chars[pos + 2] == '*' || chars[pos + 2] == '_') && pos + 3 < chars.len() && chars[pos + 3] == ' ' {
+            // Quote followed by emphasis: 'sentence."* '
+            (pos + 3, pos + 4)
+        } else if (chars[pos + 2] == '*' || chars[pos + 2] == '_')
+            && pos + 4 < chars.len()
+            && chars[pos + 3] == chars[pos + 2]
+            && chars[pos + 4] == ' '
+        {
+            // Quote followed by bold: 'sentence."** '
+            (pos + 4, pos + 5)
+        } else {
+            return false;
+        }
     } else if (next_char == '*' || next_char == '_') && pos + 2 < chars.len() && chars[pos + 2] == ' ' {
         // Sentence ends with emphasis: "sentence.* " or "sentence._ "
         (pos + 2, pos + 3)
@@ -217,10 +152,13 @@ fn is_sentence_boundary(text: &str, pos: usize, abbreviations: &HashSet<String>)
         return false;
     }
 
-    // Skip leading emphasis/strikethrough markers to find the actual first letter
+    // Skip leading emphasis/strikethrough markers and opening quotes to find the actual first letter
     let mut first_letter_pos = next_char_pos;
     while first_letter_pos < chars.len()
-        && (chars[first_letter_pos] == '*' || chars[first_letter_pos] == '_' || chars[first_letter_pos] == '~')
+        && (chars[first_letter_pos] == '*'
+            || chars[first_letter_pos] == '_'
+            || chars[first_letter_pos] == '~'
+            || is_opening_quote(chars[first_letter_pos]))
     {
         first_letter_pos += 1;
     }
@@ -276,10 +214,14 @@ fn split_into_sentences_with_set(text: &str, abbreviations: &HashSet<String>) ->
         current_sentence.push(c);
 
         if is_sentence_boundary(text, pos, abbreviations) {
-            // Consume any trailing emphasis/strikethrough markers (they belong to the current sentence)
-            while chars.peek() == Some(&'*') || chars.peek() == Some(&'_') || chars.peek() == Some(&'~') {
-                current_sentence.push(chars.next().unwrap());
-                pos += 1;
+            // Consume any trailing emphasis/strikethrough markers and quotes (they belong to the current sentence)
+            while let Some(&next) = chars.peek() {
+                if next == '*' || next == '_' || next == '~' || is_closing_quote(next) {
+                    current_sentence.push(chars.next().unwrap());
+                    pos += 1;
+                } else {
+                    break;
+                }
             }
 
             // Consume the space after the sentence
@@ -1807,8 +1749,24 @@ pub fn reflow_markdown(content: &str, options: &ReflowOptions) -> String {
                     || prev_trimmed.ends_with("?*")
                     || prev_trimmed.ends_with("._")
                     || prev_trimmed.ends_with("!_")
-                    || prev_trimmed.ends_with("?_"))
-                    && !text_ends_with_abbreviation(prev_trimmed.trim_end_matches(['*', '_']), &abbreviations);
+                    || prev_trimmed.ends_with("?_")
+                    // Quote-terminated sentences (straight and curly quotes)
+                    || prev_trimmed.ends_with(".\"")
+                    || prev_trimmed.ends_with("!\"")
+                    || prev_trimmed.ends_with("?\"")
+                    || prev_trimmed.ends_with(".'")
+                    || prev_trimmed.ends_with("!'")
+                    || prev_trimmed.ends_with("?'")
+                    || prev_trimmed.ends_with(".\u{201D}")
+                    || prev_trimmed.ends_with("!\u{201D}")
+                    || prev_trimmed.ends_with("?\u{201D}")
+                    || prev_trimmed.ends_with(".\u{2019}")
+                    || prev_trimmed.ends_with("!\u{2019}")
+                    || prev_trimmed.ends_with("?\u{2019}"))
+                    && !text_ends_with_abbreviation(
+                        prev_trimmed.trim_end_matches(['*', '_', '"', '\'', '\u{201D}', '\u{2019}']),
+                        &abbreviations,
+                    );
 
                 if has_hard_break(prev_line) || (options.sentence_per_line && ends_with_sentence) {
                     // Start a new part after hard break or complete sentence
