@@ -55,7 +55,12 @@ impl VsCodeExtension {
         Self::find_working_command(cmd).is_some()
     }
 
-    fn find_code_command() -> Result<String, String> {
+    /// Internal implementation that accepts a command checker for testing
+    #[doc(hidden)]
+    pub fn find_code_command_impl<F>(command_checker: F) -> Result<String, String>
+    where
+        F: Fn(&str) -> bool,
+    {
         // First, check if we're in an integrated terminal
         if let Ok(term_program) = std::env::var("TERM_PROGRAM") {
             let preferred_cmd = match term_program.to_lowercase().as_str() {
@@ -64,7 +69,7 @@ impl VsCodeExtension {
                     // by checking for Cursor-specific environment variables
                     if std::env::var("CURSOR_TRACE_ID").is_ok() || std::env::var("CURSOR_SETTINGS").is_ok() {
                         "cursor"
-                    } else if Self::command_exists("cursor") && !Self::command_exists("code") {
+                    } else if command_checker("cursor") && !command_checker("code") {
                         // If only cursor exists, use it
                         "cursor"
                     } else {
@@ -76,11 +81,9 @@ impl VsCodeExtension {
                 _ => "",
             };
 
-            // Verify the preferred command exists and works, return the working version
-            if !preferred_cmd.is_empty()
-                && let Some(working_cmd) = Self::find_working_command(preferred_cmd)
-            {
-                return Ok(working_cmd);
+            // Verify the preferred command exists
+            if !preferred_cmd.is_empty() && command_checker(preferred_cmd) {
+                return Ok(preferred_cmd.to_string());
             }
         }
 
@@ -88,8 +91,8 @@ impl VsCodeExtension {
         let commands = ["code", "cursor", "windsurf", "codium", "vscodium"];
 
         for cmd in &commands {
-            if let Some(working_cmd) = Self::find_working_command(cmd) {
-                return Ok(working_cmd);
+            if command_checker(cmd) {
+                return Ok(cmd.to_string());
             }
         }
 
@@ -99,8 +102,16 @@ impl VsCodeExtension {
         ))
     }
 
-    /// Find all available VS Code-compatible editors
-    pub fn find_all_editors() -> Vec<(&'static str, &'static str)> {
+    fn find_code_command() -> Result<String, String> {
+        Self::find_code_command_impl(Self::command_exists)
+    }
+
+    /// Internal implementation that accepts a command checker for testing
+    #[doc(hidden)]
+    pub fn find_all_editors_impl<F>(command_checker: F) -> Vec<(&'static str, &'static str)>
+    where
+        F: Fn(&str) -> bool,
+    {
         let editors = [
             ("code", "VS Code"),
             ("cursor", "Cursor"),
@@ -109,16 +120,19 @@ impl VsCodeExtension {
             ("vscodium", "VSCodium"),
         ];
 
-        editors
-            .into_iter()
-            .filter(|(cmd, _)| Self::command_exists(cmd))
-            .collect()
+        editors.into_iter().filter(|(cmd, _)| command_checker(cmd)).collect()
+    }
+
+    /// Find all available VS Code-compatible editors
+    pub fn find_all_editors() -> Vec<(&'static str, &'static str)> {
+        Self::find_all_editors_impl(Self::command_exists)
     }
 
     /// Get the current editor from TERM_PROGRAM if available
-    pub fn current_editor_from_env() -> Option<(&'static str, &'static str)> {
-        if let Ok(term_program) = std::env::var("TERM_PROGRAM") {
-            match term_program.to_lowercase().as_str() {
+    /// Internal implementation that accepts environment as parameters for testing
+    fn current_editor_from_env_impl(term_program: Option<&str>) -> Option<(&'static str, &'static str)> {
+        if let Some(term) = term_program {
+            match term.to_lowercase().as_str() {
                 "vscode" => {
                     if Self::command_exists("code") {
                         Some(("code", "VS Code"))
@@ -147,6 +161,10 @@ impl VsCodeExtension {
         }
     }
 
+    pub fn current_editor_from_env() -> Option<(&'static str, &'static str)> {
+        Self::current_editor_from_env_impl(std::env::var("TERM_PROGRAM").ok().as_deref())
+    }
+
     /// Check if the editor uses Open VSX by default
     fn uses_open_vsx(&self) -> bool {
         // VSCodium and some other forks use Open VSX by default
@@ -425,13 +443,39 @@ impl VsCodeExtension {
                     .map_err(|e| format!("Failed to run VS Code command: {e}"))?;
 
                 if output.status.success() {
-                    println!("{}", "✓ Successfully updated Rumdl VS Code extension!".green());
+                    // Verify the actual installed version after update
+                    match self.get_installed_version() {
+                        Ok(new_version) => {
+                            println!("{}", "✓ Successfully updated Rumdl VS Code extension!".green());
+                            println!("  New version: {}", new_version.cyan());
 
-                    // Verify the update
-                    if let Ok(new_version) = self.get_installed_version() {
-                        println!("  New version: {}", new_version.cyan());
+                            // Warn if the update didn't reach the latest version
+                            if new_version != latest_version {
+                                println!();
+                                println!(
+                                    "{}",
+                                    format!("⚠ Expected version {latest_version}, but {new_version} is installed")
+                                        .yellow()
+                                );
+                                println!("  This might indicate a caching issue or delayed marketplace propagation.");
+                                println!(
+                                    "  Try restarting your editor or running {} again later",
+                                    "rumdl vscode --update".cyan()
+                                );
+                            }
+                            Ok(())
+                        }
+                        Err(e) => {
+                            // Update succeeded but we can't verify the version
+                            println!("{}", "✓ Successfully updated Rumdl VS Code extension!".green());
+                            println!(
+                                "  {} {}",
+                                "Note:".dimmed(),
+                                format!("Could not verify version: {e}").dimmed()
+                            );
+                            Ok(())
+                        }
                     }
-                    Ok(())
                 } else {
                     let stderr = String::from_utf8_lossy(&output.stderr);
 
@@ -552,57 +596,51 @@ mod tests {
 
     #[test]
     fn test_current_editor_from_env() {
-        // Save current TERM_PROGRAM if it exists
-        let original_term = std::env::var("TERM_PROGRAM").ok();
-        let original_editor = std::env::var("EDITOR").ok();
-        let original_visual = std::env::var("VISUAL").ok();
+        // Test with no TERM_PROGRAM set
+        assert!(VsCodeExtension::current_editor_from_env_impl(None).is_none());
 
-        unsafe {
-            // Clear all environment variables that could affect the test
-            std::env::remove_var("TERM_PROGRAM");
-            std::env::remove_var("EDITOR");
-            std::env::remove_var("VISUAL");
-
-            // Test with no TERM_PROGRAM set
-            assert!(VsCodeExtension::current_editor_from_env().is_none());
-
-            // Test with VS Code TERM_PROGRAM (but command might not exist)
-            std::env::set_var("TERM_PROGRAM", "vscode");
-            let _result = VsCodeExtension::current_editor_from_env();
-            // Result depends on whether 'code' command exists
-
-            // Test with cursor TERM_PROGRAM
-            std::env::set_var("TERM_PROGRAM", "cursor");
-            let _cursor_result = VsCodeExtension::current_editor_from_env();
-            // Result depends on whether 'cursor' command exists
-
-            // Test with windsurf TERM_PROGRAM
-            std::env::set_var("TERM_PROGRAM", "windsurf");
-            let _windsurf_result = VsCodeExtension::current_editor_from_env();
-            // Result depends on whether 'windsurf' command exists
-
-            // Test with unknown TERM_PROGRAM
-            std::env::set_var("TERM_PROGRAM", "unknown-editor");
-            assert!(VsCodeExtension::current_editor_from_env().is_none());
-
-            // Test with mixed case (should work due to to_lowercase)
-            std::env::set_var("TERM_PROGRAM", "VsCode");
-            let _mixed_case_result = VsCodeExtension::current_editor_from_env();
-            // Result should be same as lowercase version
-
-            // Restore original environment variables
-            if let Some(term) = original_term {
-                std::env::set_var("TERM_PROGRAM", term);
-            } else {
-                std::env::remove_var("TERM_PROGRAM");
-            }
-            if let Some(editor) = original_editor {
-                std::env::set_var("EDITOR", editor);
-            }
-            if let Some(visual) = original_visual {
-                std::env::set_var("VISUAL", visual);
-            }
+        // Test with VS Code TERM_PROGRAM (but command might not exist)
+        let vscode_result = VsCodeExtension::current_editor_from_env_impl(Some("vscode"));
+        // Result depends on whether 'code' command exists
+        if let Some((cmd, name)) = vscode_result {
+            assert_eq!(cmd, "code");
+            assert_eq!(name, "VS Code");
         }
+
+        // Test with cursor TERM_PROGRAM
+        let cursor_result = VsCodeExtension::current_editor_from_env_impl(Some("cursor"));
+        // Result depends on whether 'cursor' command exists
+        if let Some((cmd, name)) = cursor_result {
+            assert_eq!(cmd, "cursor");
+            assert_eq!(name, "Cursor");
+        }
+
+        // Test with windsurf TERM_PROGRAM
+        let windsurf_result = VsCodeExtension::current_editor_from_env_impl(Some("windsurf"));
+        // Result depends on whether 'windsurf' command exists
+        if let Some((cmd, name)) = windsurf_result {
+            assert_eq!(cmd, "windsurf");
+            assert_eq!(name, "Windsurf");
+        }
+
+        // Test with unknown TERM_PROGRAM - should always return None
+        assert!(VsCodeExtension::current_editor_from_env_impl(Some("unknown-editor")).is_none());
+
+        // Test with mixed case (should work due to to_lowercase)
+        let mixed_case_result = VsCodeExtension::current_editor_from_env_impl(Some("VsCode"));
+        // Should behave the same as lowercase version
+        assert_eq!(
+            mixed_case_result,
+            VsCodeExtension::current_editor_from_env_impl(Some("vscode"))
+        );
+
+        // Test edge cases
+        assert!(VsCodeExtension::current_editor_from_env_impl(Some("")).is_none());
+        assert!(VsCodeExtension::current_editor_from_env_impl(Some("   ")).is_none());
+        assert!(
+            VsCodeExtension::current_editor_from_env_impl(Some("VSCODE")).is_some()
+                || !VsCodeExtension::command_exists("code")
+        );
     }
 
     #[test]
