@@ -64,7 +64,7 @@ pub fn test_character_ranges(test: CharacterRangeTest) {
     let rule = create_rule_by_name(test.rule_name).unwrap_or_else(|| panic!("Unknown rule: {}", test.rule_name));
 
     // Run the rule check
-    let ctx = LintContext::new(test.content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(test.content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let warnings = rule
         .check(&ctx)
         .unwrap_or_else(|e| panic!("Rule {} failed to check content: {}", test.rule_name, e));
@@ -191,7 +191,7 @@ pub fn extract_highlighted_text(content: &str, warning: &LintWarning) -> String
 /// Create a rule instance by name for dynamic testing
 pub fn create_rule_by_name(rule_name: &str) -> Option<Box<dyn Rule>> {
     match rule_name {
-        "MD001" => Some(Box::new(MD001HeadingIncrement)),
+        "MD001" => Some(Box::new(MD001HeadingIncrement::default())),
         "MD003" => Some(Box::new(MD003HeadingStyle::new(HeadingStyle::Consistent))),
         "MD004" => Some(Box::new(MD004UnorderedListStyle::new(UnorderedListStyle::Consistent))),
         "MD005" => Some(Box::new(MD005ListIndent::default())),
@@ -214,7 +214,7 @@ pub fn create_rule_by_name(rule_name: &str) -> Option<Box<dyn Rule>> {
         "MD028" => Some(Box::new(MD028NoBlanksBlockquote)),
         "MD030" => Some(Box::new(MD030ListMarkerSpace::new(1, 1, 1, 1))),
         "MD031" => Some(Box::new(MD031BlanksAroundFences::default())),
-        "MD032" => Some(Box::new(MD032BlanksAroundLists)),
+        "MD032" => Some(Box::new(MD032BlanksAroundLists::default())),
         "MD033" => Some(Box::new(MD033NoInlineHtml::new())),
         "MD034" => Some(Box::new(MD034NoBareUrls)),
         "MD035" => Some(Box::new(MD035HRStyle::new("consistent".to_string()))),
