@@ -6,7 +6,7 @@ use rumdl_lib::rules::MD023HeadingStartLeft;
 fn test_valid_headings() {
     let rule = MD023HeadingStartLeft;
     let content = "# Heading 1\n## Heading 2\nHeading 3\n---";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_valid_headings() {
 fn test_invalid_indented_headings() {
     let rule = MD023HeadingStartLeft;
     let content = "  # Indented\n    ## Indented\n  Heading\n  ---";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty());
 }
@@ -24,7 +24,7 @@ fn test_invalid_indented_headings() {
 fn test_fix_indented_headings() {
     let rule = MD023HeadingStartLeft;
     let content = "  # Indented\n    ## Indented\n  Heading\n  ---";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert!(fixed.contains("# Indented"));
     assert!(fixed.contains("## Indented"));
@@ -34,7 +34,7 @@ fn test_fix_indented_headings() {
 fn test_mixed_content() {
     let rule = MD023HeadingStartLeft;
     let content = "# Good heading\n   # Bad heading\nNormal text\n  ## Another bad one";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
 }
@@ -43,7 +43,7 @@ fn test_mixed_content() {
 fn test_closed_atx_headings() {
     let rule = MD023HeadingStartLeft;
     let content = "   # Heading 1 #\n  ## Heading 2 ##";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
     let fixed = rule.fix(&ctx).unwrap();
@@ -54,7 +54,7 @@ fn test_closed_atx_headings() {
 fn test_preserve_heading_content() {
     let rule = MD023HeadingStartLeft;
     let content = "   # Complex *heading* with **markdown**";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, "# Complex *heading* with **markdown**");
 }
@@ -63,7 +63,7 @@ fn test_preserve_heading_content() {
 fn test_ignore_non_headings() {
     let rule = MD023HeadingStartLeft;
     let content = "   Not a heading\n  Also not a heading";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -72,7 +72,7 @@ fn test_ignore_non_headings() {
 fn test_multiple_heading_levels() {
     let rule = MD023HeadingStartLeft;
     let content = "   # H1\n  ## H2\n ### H3\n#### H4";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 3); // Only the indented ones should be flagged
     let fixed = rule.fix(&ctx).unwrap();
