@@ -6,7 +6,7 @@ use rumdl_lib::rules::MD033NoInlineHtml;
 fn test_no_html() {
     let rule = MD033NoInlineHtml::default();
     let content = "Just regular markdown\n\n# Heading\n\n* List item";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -15,7 +15,7 @@ fn test_no_html() {
 fn test_simple_html_tag() {
     let rule = MD033NoInlineHtml::default();
     let content = "Some <b>bold</b> text";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Only reports opening tags (only opening tags)
     assert_eq!(result.len(), 1); // Only <b>
@@ -27,7 +27,7 @@ fn test_simple_html_tag() {
 fn test_self_closing_tag() {
     let rule = MD033NoInlineHtml::default();
     let content = "An image: <img src=\"test.png\" />";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Current implementation detects self-closing HTML tags
     assert_eq!(result.len(), 1);
@@ -39,7 +39,7 @@ fn test_self_closing_tag() {
 fn test_allowed_elements() {
     let rule = MD033NoInlineHtml::with_allowed(vec!["b".to_string(), "i".to_string()]);
     let content = "Some <b>bold</b> and <i>italic</i> but not <u>underlined</u>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0);
 }
@@ -48,7 +48,7 @@ fn test_allowed_elements() {
 fn test_html_in_code_block() {
     let rule = MD033NoInlineHtml::default();
     let content = "Normal text\n```\n<div>This is in a code block</div>\n```\nMore text";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -57,7 +57,7 @@ fn test_html_in_code_block() {
 fn test_fix_html_tags() {
     let rule = MD033NoInlineHtml::default();
     let content = "Some <b>bold</b> text";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, content);
 }
@@ -66,7 +66,7 @@ fn test_fix_html_tags() {
 fn test_fix_self_closing_tags() {
     let rule = MD033NoInlineHtml::default();
     let content = "Line break<br/>here";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, content);
 }
@@ -75,7 +75,7 @@ fn test_fix_self_closing_tags() {
 fn test_multiple_tags() {
     let rule = MD033NoInlineHtml::default();
     let content = "<div><p>Nested</p></div>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Only reports opening tags (only opening tags)
     assert_eq!(result.len(), 2); // Only <div> and <p>
@@ -87,7 +87,7 @@ fn test_multiple_tags() {
 fn test_attributes() {
     let rule = MD033NoInlineHtml::default();
     let content = "<div class=\"test\" id=\"main\">Content</div>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Only reports opening tags (only opening tags)
     assert_eq!(result.len(), 1); // Only <div>
@@ -98,7 +98,7 @@ fn test_attributes() {
 fn test_mixed_content() {
     let rule = MD033NoInlineHtml::default();
     let content = "# Heading\n\n<div>HTML content</div>\n\n* List item\n\n<span>More HTML</span>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Only reports opening tags (only opening tags)
     // Two lines with HTML: line 3 and line 7
@@ -113,7 +113,7 @@ fn test_mixed_content() {
 fn test_preserve_content() {
     let rule = MD033NoInlineHtml::default();
     let content = "Text with <strong>important</strong> content";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, content);
 }
@@ -122,7 +122,7 @@ fn test_preserve_content() {
 fn test_multiline_html() {
     let rule = MD033NoInlineHtml::default();
     let content = "<div>\nMultiline\ncontent\n</div>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Only detects opening tags (only opening tags)
     assert_eq!(result.len(), 1);
@@ -132,7 +132,7 @@ fn test_multiline_html() {
 fn test_ignore_code_spans() {
     let rule = MD033NoInlineHtml::default();
     let content = "Use `<div>` for a block element";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -143,25 +143,25 @@ fn test_complex_code_block_patterns() {
 
     // Test with mixed fence styles
     let content = "Text\n```\n<div>Code block 1</div>\n```\nMore text\n~~~\n<span>Code block 2</span>\n~~~\nEnd text";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0);
 
     // Test with code block at start of document
     let content = "```\n<div>Starts with code</div>\n```\nText with <b>bold</b>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1); // Only <b> outside code block
 
     // Test with code block at end of document
     let content = "Text with <i>italic</i>\n```\n<div>Ends with code</div>\n```";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1); // Only <i> outside code block
 
     // Test adjacent code blocks
     let content = "```\n<div>Block 1</div>\n```\n```\n<span>Block 2</span>\n```";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0);
 }
@@ -172,25 +172,25 @@ fn test_code_span_binary_search() {
 
     // Test HTML tag immediately before a code span
     let content = "<span>`code`</span>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1); // Only <span> outside code span
 
     // Test HTML tag immediately after a code span
     let content = "`code`<div>text</div>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1); // Only <div> outside code span
 
     // Test HTML tag exactly at position boundaries
     let content = "Text `<div>` more text";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0); // <div> is inside code span
 
     // Test many code spans to trigger binary search optimization
     let content = "`1` `2` `3` `4` `5` `6` `7` `8` `9` `10` `11` `12` <span>text</span>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1); // Only <span> outside code spans
 }
@@ -201,17 +201,17 @@ fn test_fix_preserves_structure_html() {
 
     // Verify HTML fix is a no-op (output equals input)
     let content = "Normal <b>bold</b>\n```\n<div>Code block</div>\n```\nMore <i>italic</i>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, content);
 
     let content = "Text with `<span>` and <div>block</div>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, content);
 
     let content = "<div><p>Nested content</p></div>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let fixed = rule.fix(&ctx).unwrap();
     assert_eq!(fixed, content);
 }
@@ -223,7 +223,7 @@ fn test_markdown_comments() {
     // Test with markdownlint comments
     let content =
         "Some content\n<!-- markdownlint-disable -->\nIgnored content\n<!-- markdownlint-enable -->\nMore content";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // These should not be flagged as HTML tags
@@ -231,7 +231,7 @@ fn test_markdown_comments() {
 
     // Test with regular HTML comments
     let content = "Some content\n<!-- This is a comment -->\nMore content";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Comments should not be flagged
@@ -248,7 +248,7 @@ fn test_urls_in_angle_brackets() {
                    Secure transfer: <ftps://secure.example.com/data>\n\
                    Contact us: <mailto:user@example.com>\n\
                    Complex URL: <https://marketplace.visualstudio.com/items?itemName=ms-vscode-remote.remote-containers>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // URLs in angle brackets should not be flagged as HTML
@@ -266,7 +266,7 @@ fn test_mixed_urls_and_html() {
     let content = "Visit <https://example.com> for more info.\n\
                    This has <strong>real HTML</strong> tags.\n\
                    Email us at <mailto:test@example.com> or use <em>emphasis</em>.";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should only flag the real HTML tags (opening tags only), not the URLs
@@ -296,22 +296,21 @@ fn test_edge_case_urls() {
     let rule = MD033NoInlineHtml::default();
 
     // Test edge cases that might be confused
+    // Now MD033 only flags actual HTML elements, not placeholder syntax like <notaurl>
     let content = "Not a URL: <notaurl>\n\
                    Real URL: <https://example.com>\n\
                    Fake tag: <https>\n\
                    Real tag: <div>";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
-    // Should flag <notaurl>, <https>, and <div> but not the real URL <https://example.com>
-    assert_eq!(result.len(), 3); // Only opening tags
+    // Should only flag <div> - the only actual HTML element
+    // <notaurl> and <https> are placeholder syntax, not HTML elements
+    // <https://example.com> is a valid autolink URL
+    assert_eq!(result.len(), 1);
 
     let flagged_positions: Vec<(usize, usize)> = result.iter().map(|w| (w.line, w.column)).collect();
 
-    // <notaurl> should be flagged (line 1)
-    assert!(flagged_positions.contains(&(1, 12)));
-    // <https> should be flagged (line 3) - not a valid URL, looks like HTML tag
-    assert!(flagged_positions.contains(&(3, 11)));
     // <div> should be flagged (line 4)
     assert!(flagged_positions.contains(&(4, 11)));
 }
@@ -331,7 +330,7 @@ Indented HTML (CommonMark code block):
 
 More regular HTML: <span>should be flagged</span>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let rule = MD033NoInlineHtml::default();
     let warnings = rule.check(&ctx).unwrap();
 
@@ -368,7 +367,7 @@ Tab indented (code block):
 
 Regular HTML: <p>flagged</p>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let rule = MD033NoInlineHtml::default();
     let warnings = rule.check(&ctx).unwrap();
 
@@ -399,7 +398,7 @@ Mixed indented content (all in code block):
 
 Back to regular: <span>flagged</span>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let rule = MD033NoInlineHtml::default();
     let warnings = rule.check(&ctx).unwrap();
 
@@ -430,7 +429,7 @@ Indented code block with blank lines:
 
 Regular again: <em>flagged</em>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let rule = MD033NoInlineHtml::default();
     let warnings = rule.check(&ctx).unwrap();
 
@@ -465,7 +464,7 @@ Indented code block:
 
 Regular: <span>flagged</span>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let rule = MD033NoInlineHtml::default();
     let warnings = rule.check(&ctx).unwrap();
 
@@ -509,7 +508,7 @@ More indented:
 
 Regular: <em>flagged</em>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let rule = MD033NoInlineHtml::default();
     let warnings = rule.check(&ctx).unwrap();
 
@@ -524,6 +523,10 @@ Regular: <em>flagged</em>"#;
 
 #[test]
 fn test_md033_edge_cases_indentation() {
+    // Per CommonMark spec, an indented code block requires:
+    // 1. A blank line before it (or start of document)
+    // 2. 4+ spaces of indentation
+    // If a non-indented line appears, it breaks the code block
     let content = r#"# Test Document
 
 Regular: <div>flagged</div>
@@ -533,25 +536,25 @@ Mixed indentation levels:
     <div>4 spaces - code block</div>
         <p>8 spaces - still code block</p>
    <span>3 spaces - NOT code block</span>
-    <em>4 spaces again - code block</em>
+    <em>4 spaces - but code block was broken by line 9</em>
 
 Regular: <strong>flagged</strong>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let rule = MD033NoInlineHtml::default();
     let warnings = rule.check(&ctx).unwrap();
 
     let flagged_lines: Vec<usize> = warnings.iter().map(|w| w.line).collect();
 
-    // Should flag regular HTML and 3-space indented
+    // Should flag regular HTML, 3-space indented, and line 10 (code block broken by line 9)
     assert!(flagged_lines.contains(&3)); // Regular
-    assert!(flagged_lines.contains(&9)); // 3 spaces (not code block)
+    assert!(flagged_lines.contains(&9)); // 3 spaces breaks code block
+    assert!(flagged_lines.contains(&10)); // 4 spaces but code block was broken
     assert!(flagged_lines.contains(&12)); // Regular
 
-    // Should NOT flag 4+ space indented (code blocks)
-    assert!(!flagged_lines.contains(&7)); // 4 spaces
-    assert!(!flagged_lines.contains(&8)); // 8 spaces
-    assert!(!flagged_lines.contains(&10)); // 4 spaces again
+    // Should NOT flag 4+ space indented within code block
+    assert!(!flagged_lines.contains(&7)); // 4 spaces - starts code block
+    assert!(!flagged_lines.contains(&8)); // 8 spaces - continues code block
 }
 
 #[test]
@@ -573,7 +576,7 @@ Regular: <div>flagged</div>
 
 Regular: <strong>flagged</strong>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let rule = MD033NoInlineHtml::default();
     let warnings = rule.check(&ctx).unwrap();
 
@@ -613,7 +616,7 @@ And fenced code blocks should be ignored:
 
 Back to regular: <em>flagged</em>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let rule = MD033NoInlineHtml::default();
     let warnings = rule.check(&ctx).unwrap();
 
@@ -662,7 +665,7 @@ This should be flagged: <div>real HTML</div>
 
 More real HTML: <p>flagged</p>"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should only flag HTML outside comments (opening tags only)
