@@ -15,7 +15,7 @@ fn test_md038_nested_backticks_not_flagged() {
     ];
 
     for case in test_cases {
-        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let warnings = rule.check(&ctx).unwrap();
         assert_eq!(
             warnings.len(),
@@ -29,17 +29,33 @@ fn test_md038_nested_backticks_not_flagged() {
 fn test_md038_still_detects_regular_spaces() {
     let rule = MD038NoSpaceInCode::new();
 
-    // These should still be detected as having spaces (no nested backticks)
-    let cases_with_warnings = vec![
-        "Code with ` plain text ` should flag spaces",
+    // CommonMark: Single space at BOTH ends is valid (spaces are stripped)
+    // These all have space at both ends, so they should NOT be flagged
+    let valid_commonmark_cases = vec![
+        "Code with ` plain text ` should not flag spaces",
         "Double ` spaces here ` with spaces",
         "Example ` code ` here",
     ];
 
-    for case in cases_with_warnings {
-        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard);
+    for case in valid_commonmark_cases {
+        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let warnings = rule.check(&ctx).unwrap();
-        assert!(!warnings.is_empty(), "Should detect spaces in: {case}");
+        assert!(
+            warnings.is_empty(),
+            "Single space at both ends is valid CommonMark: {case}"
+        );
+    }
+
+    // Cases with space at only ONE end should be flagged
+    let invalid_cases = vec![
+        "Code with ` leading only` should flag",
+        "Code with `trailing only ` should flag",
+    ];
+
+    for case in invalid_cases {
+        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard, None);
+        let warnings = rule.check(&ctx).unwrap();
+        assert!(!warnings.is_empty(), "Space at only one end should be flagged: {case}");
     }
 }
 
@@ -54,7 +70,7 @@ fn test_md038_lenient_mode_allows_nested_backticks() {
     ];
 
     for case in test_cases {
-        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard);
+        let ctx = LintContext::new(case, rumdl_lib::config::MarkdownFlavor::Standard, None);
         let warnings = rule.check(&ctx).unwrap();
         assert_eq!(
             warnings.len(),
@@ -71,7 +87,7 @@ fn test_md038_documentation_example() {
 
     // This example shows why we don't fix spaces when backticks are nested
     let content = "To show a backtick in code, use `` ` `` or ``` `` ```";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let warnings = rule.check(&ctx).unwrap();
 
     assert_eq!(warnings.len(), 0, "Nested backtick examples should not be flagged");
