@@ -7,7 +7,7 @@ use rumdl_lib::rules::code_block_utils::CodeBlockStyle;
 fn test_consistent_fenced_blocks() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
     let content = "# Code blocks\n\n```\ncode here\n```\n\n```rust\nmore code\n```";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -16,7 +16,7 @@ fn test_consistent_fenced_blocks() {
 fn test_consistent_indented_blocks() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Indented);
     let content = "# Code blocks\n\n    code here\n    more code\n\n    another block\n    continues";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -25,7 +25,7 @@ fn test_consistent_indented_blocks() {
 fn test_mixed_blocks_prefer_fenced() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
     let content = "# Mixed blocks\n\n```\nfenced block\n```\n\n    indented block";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     let fixed = rule.fix(&ctx).unwrap();
@@ -44,7 +44,7 @@ fn test_mixed_blocks_prefer_fenced() {
 fn test_mixed_blocks_prefer_indented() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Indented);
     let content = "# Mixed blocks\n\n```\nfenced block\n```\n\n    indented block";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(
         result.len(),
@@ -64,7 +64,7 @@ fn test_mixed_blocks_prefer_indented() {
 fn test_consistent_style_fenced_first() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
     let content = "# Mixed blocks\n\n```\nfenced block\n```\n\n    indented block";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty(), "Should detect inconsistent code blocks");
     let fixed = rule.fix(&ctx).unwrap();
@@ -84,7 +84,7 @@ fn test_consistent_style_indented_first() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
     // One indented and one fenced block - tie prefers fenced
     let content = "# Mixed blocks\n\n    indented block\n\n```\nfenced block\n```";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty(), "Should detect inconsistent code blocks");
     let fixed = rule.fix(&ctx).unwrap();
@@ -103,7 +103,7 @@ fn test_consistent_style_indented_first() {
 fn test_empty_content() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
     let content = "";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -112,7 +112,7 @@ fn test_empty_content() {
 fn test_no_code_blocks() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
     let content = "# Just a heading\n\nSome regular text\n\n> A blockquote";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -121,7 +121,7 @@ fn test_no_code_blocks() {
 fn test_fenced_with_language() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
     let content = "```rust\nlet x = 42;\n```\n\n```python\nprint('hello')\n```";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -130,7 +130,7 @@ fn test_fenced_with_language() {
 fn test_convert_indented_preserves_content() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
     let content = "    let x = 42;\n    println!(\"{}\", x);";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(!result.is_empty(), "Should detect indented code blocks");
     let fixed = rule.fix(&ctx).unwrap();
@@ -166,7 +166,7 @@ console.log("Hello");
 The above shows proper markdown syntax.
 "#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should not detect any issues with markdown example blocks
@@ -184,7 +184,7 @@ The above shows proper markdown syntax.
 fn test_unclosed_code_block() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
     let content = "# Test\n\n```python\ndef hello():\n    print('world')\n\nThis content is inside an unclosed block.";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1, "Should detect exactly one unclosed code block");
     assert!(
@@ -202,7 +202,7 @@ fn test_unclosed_code_block() {
 fn test_unclosed_tilde_code_block() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
     let content = "# Test\n\n~~~javascript\nfunction test() {\n  return 42;\n}\n\nMore content here.";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1, "Should detect exactly one unclosed code block");
     assert!(
@@ -223,7 +223,7 @@ fn test_unclosed_tilde_code_block() {
 fn test_nested_code_block_opening() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
     let content = "# Test\n\n```bash\n\n```markdown\n\n# Hello world\n\n```\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert_eq!(result.len(), 1, "Should detect exactly one nested code block issue");
@@ -250,7 +250,7 @@ fn test_nested_code_block_opening() {
 fn test_nested_code_block_different_languages() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
     let content = "```python\n\n```javascript\ncode here\n```\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert_eq!(result.len(), 1, "Should detect nested opening");
@@ -269,7 +269,7 @@ fn test_nested_markdown_blocks_allowed() {
     // But based on our conversation, we're now flagging ALL nested openings
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
     let content = "```bash\n\n```markdown\n# Example\n```\n```\n";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // This test case has both nested opening AND unclosed blocks, so we get multiple warnings
@@ -302,7 +302,7 @@ fn main() {
 ```
 ```"#; // Close the markdown block
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should not flag anything - all nested blocks are inside markdown documentation
@@ -318,7 +318,7 @@ fn test_nested_same_language() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
     let content = "```python\n\n```python\nprint('nested')\n```";
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert_eq!(result.len(), 1, "Should flag nested non-markdown blocks");
@@ -343,7 +343,7 @@ print("code")
 More content
 ````"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert!(result.is_empty(), "Deeply nested markdown blocks should be allowed");
@@ -355,7 +355,7 @@ fn test_mixed_fence_lengths() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
     let content = "````python\n\n```javascript\ncode\n```\n\n````";
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should work correctly with 4-backtick fences
@@ -368,7 +368,7 @@ fn test_adjacent_code_blocks() {
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
     let content = "```rust\ncode1\n```\n```python\ncode2\n```";
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert!(result.is_empty(), "Adjacent blocks should not be flagged as nested");
@@ -376,16 +376,21 @@ fn test_adjacent_code_blocks() {
 
 #[test]
 fn test_markdown_block_at_end() {
-    // Test markdown block that ends the document
+    // Test markdown block that ends the document with a proper closing fence.
+    // Per CommonMark spec, ```rust inside the markdown block is content (not a closing fence
+    // because it has "rust" after), and the final ``` closes the markdown block.
     let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Consistent);
     let content = "# Doc\n\n```markdown\n## Example\n\n```rust\nfn test() {}\n```";
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
-    // The markdown block is unclosed but contains properly formatted examples
-    assert_eq!(result.len(), 1, "Should flag unclosed markdown block");
-    assert!(result[0].message.contains("never closed"));
+    // The markdown block is properly closed by the final ```
+    // The ```rust is content (not a closing fence because "rust" follows)
+    assert!(
+        result.is_empty(),
+        "Should not flag markdown block that is properly closed"
+    );
 }
 
 #[test]
@@ -403,12 +408,97 @@ fn test_fence_in_list_context() {
        pass
    ```"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert!(result.is_empty(), "Code blocks in lists should not cause issues");
 }
 
+#[test]
+fn test_issue_257_fence_on_list_marker_line() {
+    // Issue 257: Fence marker immediately following list marker on same line
+    // The closing fence is indented to match list content, not the opening fence
+    let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+
+    // Pattern 1: Fence immediately after list marker
+    let content = r#"- Sample code:
+- ```java
+      List<Map<String,String>> inputs = new List<Map<String,String>>();
+  ```"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should NOT report unclosed block - the indented ``` closes the block
+    let unclosed_warnings: Vec<_> = result.iter().filter(|w| w.message.contains("never closed")).collect();
+    assert!(
+        unclosed_warnings.is_empty(),
+        "List-indented closing fence should be recognized: {unclosed_warnings:?}"
+    );
+
+    // Pattern 2: Multiple list items with inline fences
+    let content2 = r#"- ```python
+  print("hello")
+  ```
+- ```rust
+  fn main() {}
+  ```"#;
+
+    let ctx2 = LintContext::new(content2, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result2 = rule.check(&ctx2).unwrap();
+
+    let unclosed2: Vec<_> = result2.iter().filter(|w| w.message.contains("never closed")).collect();
+    assert!(
+        unclosed2.is_empty(),
+        "Multiple inline fences should all be recognized as closed: {unclosed2:?}"
+    );
+
+    // Pattern 3: Nested list with inline fence
+    let content3 = r#"- Outer item
+  - ```bash
+    echo "nested"
+    ```"#;
+
+    let ctx3 = LintContext::new(content3, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result3 = rule.check(&ctx3).unwrap();
+
+    let unclosed3: Vec<_> = result3.iter().filter(|w| w.message.contains("never closed")).collect();
+    assert!(
+        unclosed3.is_empty(),
+        "Nested list inline fence should be recognized as closed: {unclosed3:?}"
+    );
+
+    // Pattern 4: Tilde fences in list context
+    let content4 = r#"- ~~~python
+  print("tilde fence")
+  ~~~"#;
+
+    let ctx4 = LintContext::new(content4, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result4 = rule.check(&ctx4).unwrap();
+
+    let unclosed4: Vec<_> = result4.iter().filter(|w| w.message.contains("never closed")).collect();
+    assert!(
+        unclosed4.is_empty(),
+        "Tilde fence in list should be recognized as closed: {unclosed4:?}"
+    );
+
+    // Pattern 5: Longer fence in list (4+ backticks)
+    let content5 = r#"- ````markdown
+  ```python
+  nested code
+  ```
+  ````"#;
+
+    let ctx5 = LintContext::new(content5, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result5 = rule.check(&ctx5).unwrap();
+
+    let unclosed5: Vec<_> = result5.iter().filter(|w| w.message.contains("never closed")).collect();
+    assert!(
+        unclosed5.is_empty(),
+        "Longer fence in list should be recognized as closed: {unclosed5:?}"
+    );
+}
+
 #[test]
 fn test_python_traceback_tilde_markers() {
     // Test that Python traceback decoration lines are not treated as code fences
@@ -435,7 +525,7 @@ ValueError: Empty sequence not allowed
 The `~~~~~~~~^^^^` markers show where the error occurred.
 "#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert!(
@@ -468,7 +558,7 @@ print("~=~=~=~=~=~=~=~=~=~")
 All the above should be fine.
 "#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert!(
@@ -500,7 +590,7 @@ Five tildes with trailing spaces
 ~~~~~
 "#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert!(result.is_empty(), "Valid tilde fences should work correctly");
@@ -523,7 +613,7 @@ fn test_invalid_fence_patterns() {
 The code block above should be properly closed.
 "#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert!(
@@ -549,7 +639,7 @@ fn test_issue_27_html_blocks_not_indented_code() {
 >>> name = "Trey"
 ```"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     assert!(
@@ -576,7 +666,7 @@ Traceback (most recent call last):
 TypeError: can only concatenate str (not "int") to str
 ```"#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should not flag the ~~~ or ^ characters inside the fenced block
@@ -586,3 +676,144 @@ TypeError: can only concatenate str (not "int") to str
         "MD046 should not flag content inside fenced code blocks (issue #118)"
     );
 }
+
+#[test]
+fn test_issue_285_blockquote_indented_content() {
+    // Issue #285: Indented content inside blockquotes should not be flagged as indented code blocks
+    // When content after `>` has 4+ spaces, it's blockquote content, not a document-level code block
+    let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+    let content = r#"# Issue 285 - MD046 false positive
+
+But as we see in the history file, the `-L` and `-S` flags are used:
+>      -S socket-path
+>                    Specify a full alternative path to the server socket.
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result = rule.check(&ctx).unwrap();
+
+    assert!(
+        result.is_empty(),
+        "Indented content inside blockquotes should not be flagged as indented code blocks (issue #285)"
+    );
+}
+
+#[test]
+fn test_blockquote_with_heavily_indented_content() {
+    // Test various levels of indentation inside blockquotes
+    let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+    let content = r#"# Blockquote Indentation Tests
+
+> Normal blockquote content
+>     Four spaces (would be code block outside blockquote)
+>         Eight spaces
+>              Twelve spaces
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result = rule.check(&ctx).unwrap();
+
+    assert!(
+        result.is_empty(),
+        "Heavily indented blockquote content should not trigger MD046"
+    );
+}
+
+#[test]
+fn test_blockquote_code_block_inside() {
+    // Actual fenced code blocks INSIDE blockquotes should still be detected properly
+    let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+    let content = r#"# Fenced Code Inside Blockquote
+
+> Here's some code:
+>
+> ```python
+> def hello():
+>     print("Hello from blockquote")
+> ```
+>
+> That was the code.
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result = rule.check(&ctx).unwrap();
+
+    assert!(
+        result.is_empty(),
+        "Fenced code blocks inside blockquotes should work correctly"
+    );
+}
+
+#[test]
+fn test_nested_blockquote_with_indentation() {
+    // Test nested blockquotes with indented content
+    let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+    let content = r#"# Nested Blockquotes
+
+> Outer blockquote
+>> Inner blockquote
+>>     Indented content in inner blockquote
+>>          More indentation
+> Back to outer
+>     Indented in outer
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result = rule.check(&ctx).unwrap();
+
+    assert!(
+        result.is_empty(),
+        "Nested blockquotes with indentation should not trigger MD046"
+    );
+}
+
+#[test]
+fn test_blockquote_then_indented_code() {
+    // Test that actual indented code blocks AFTER blockquotes are still detected
+    let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+    let content = r#"# Blockquote Then Code
+
+> This is a blockquote
+> with multiple lines
+
+    This is actual indented code (after the blockquote)
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result = rule.check(&ctx).unwrap();
+
+    // Should detect the indented code block after the blockquote
+    assert_eq!(
+        result.len(),
+        1,
+        "Indented code block after blockquote should still be detected"
+    );
+}
+
+#[test]
+fn test_mixed_blockquote_and_code() {
+    // Test mix of blockquotes and code blocks
+    let rule = MD046CodeBlockStyle::new(CodeBlockStyle::Fenced);
+    let content = r#"# Mixed Content
+
+> Blockquote with indented content:
+>     -L flag description
+>     -S socket-path description
+
+```python
+# This is actual fenced code
+print("hello")
+```
+
+> Another blockquote
+>     More indented content
+"#;
+
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
+    let result = rule.check(&ctx).unwrap();
+
+    assert!(
+        result.is_empty(),
+        "Mixed blockquotes and fenced code blocks should work correctly"
+    );
+}
