@@ -7,7 +7,7 @@ use rumdl_lib::rules::MD052ReferenceLinkImages;
 fn test_valid_reference_link() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "[example][id]\n\n[id]: http://example.com";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -19,7 +19,7 @@ fn test_valid_reference_links_multiple() {
 
 [ref1]: http://example.com/1
 [ref2]: http://example.com/2"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -29,7 +29,7 @@ fn test_valid_reference_links_multiple() {
 fn test_invalid_reference_link() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "[example][id]\n\n[other]: http://example.com";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "Reference 'id' not found");
@@ -43,7 +43,7 @@ fn test_missing_multiple_definitions() {
 [link3][ref3]
 
 [ref1]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
 }
@@ -53,7 +53,7 @@ fn test_missing_multiple_definitions() {
 fn test_invalid_reference_image() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "![example][id]\n\n[other]: http://example.com/image.jpg";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "Reference 'id' not found");
@@ -63,7 +63,7 @@ fn test_invalid_reference_image() {
 fn test_valid_reference_image() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "![example][id]\n\n[id]: http://example.com/image.jpg";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -73,7 +73,7 @@ fn test_valid_reference_image() {
 fn test_case_insensitive() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "[example][ID]\n\n[id]: http://example.com";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -86,7 +86,7 @@ fn test_case_insensitive_mixed() {
 [Link 3][ref]
 
 [ReF]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -98,7 +98,7 @@ fn test_full_reference_link() {
     let content = r#"This is a [full reference link][label].
 
 [label]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -107,7 +107,7 @@ fn test_full_reference_link() {
 fn test_full_reference_link_missing() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "This is a [full reference link][label].";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "Reference 'label' not found");
@@ -120,7 +120,7 @@ fn test_collapsed_reference_link() {
     let content = r#"This is a [collapsed reference][] link.
 
 [collapsed reference]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -129,7 +129,7 @@ fn test_collapsed_reference_link() {
 fn test_collapsed_reference_link_missing() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "This is a [collapsed reference][] link.";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "Reference 'collapsed reference' not found");
@@ -140,18 +140,20 @@ fn test_collapsed_reference_link_missing() {
 fn test_shortcut_reference() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "[example]\n\n[example]: http://example.com";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
 
 #[test]
 fn test_invalid_shortcut_reference() {
+    // Shortcut references like [example] are NOT checked by default (shortcut_syntax: false)
+    // This test verifies that default behavior matches markdownlint
     let rule = MD052ReferenceLinkImages::new();
     let content = "[example]\n\n[other]: http://example.com";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
-    assert_eq!(result.len(), 1);
+    assert_eq!(result.len(), 0, "Shortcut references are not checked by default");
 }
 
 #[test]
@@ -161,7 +163,7 @@ fn test_shortcut_vs_inline_link() {
     let content = r#"This is an [inline link](http://example.com) and a [shortcut].
 
 [shortcut]: http://example.com/shortcut"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -175,7 +177,7 @@ Second [reference][same]
 Third [reference][same]
 
 [same]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -186,7 +188,7 @@ fn test_multiple_references_same_undefined() {
     let content = r#"First [reference][missing]
 Second [reference][missing]
 Third [reference][missing]"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Should only report once for duplicate undefined references
     assert_eq!(result.len(), 1);
@@ -207,7 +209,7 @@ But this \[text][undefined] has [undefined] as a reference link.
 [ref1]: http://example.com/1
 [ref2]: http://example.com/2
 [undefined]: http://example.com/undefined"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -219,7 +221,7 @@ fn test_partially_escaped_brackets() {
     let content = r#"This is \[escaped text][ref] where [ref] needs definition.
 
 [ref]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -230,16 +232,16 @@ fn test_escaped_brackets_with_undefined_ref() {
     // The pattern \[text][undefined] should not detect [undefined] as a reference
     // because the entire construct is treated as escaped/literal text in CommonMark
     let content = r#"This is \[escaped][undefined] but undefined is not defined."#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 0);
 
-    // However, a separate [undefined] should still be detected
+    // A separate [undefined] is a shortcut reference - NOT checked by default
+    // (shortcut_syntax is false by default)
     let content2 = r#"This is \[escaped] and [undefined] but undefined is not defined."#;
-    let ctx2 = LintContext::new(content2, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx2 = LintContext::new(content2, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result2 = rule.check(&ctx2).unwrap();
-    assert_eq!(result2.len(), 1);
-    assert_eq!(result2[0].message, "Reference 'undefined' not found");
+    assert_eq!(result2.len(), 0, "Shortcut references are not checked by default");
 }
 
 #[test]
@@ -250,7 +252,7 @@ fn test_escaped_image_brackets() {
 This is a real image: ![image][ref]
 
 [ref]: http://example.com/image.jpg"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -265,7 +267,7 @@ fn test_references_at_beginning() {
 # Document
 
 Using [link1][ref1] and [link2][ref2]."#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -281,7 +283,7 @@ Using [link1][ref1] here.
 [ref2]: http://example.com/2
 
 And [link2][ref2] here."#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -297,7 +299,7 @@ More text here.
 
 [ref1]: http://example.com/1
 [ref2]: http://example.com/2"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -315,7 +317,7 @@ Image: ![alt][image]
 [collapsed]: http://example.com/collapsed
 [shortcut]: http://example.com/shortcut
 [image]: http://example.com/image.jpg"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -330,7 +332,7 @@ fn test_code_blocks_ignored() {
 [real][ref] should be checked
 
 [ref]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -342,7 +344,7 @@ fn test_inline_links_not_checked() {
 ![Inline image](http://example.com/image.jpg) should not be checked.
 
 But [reference][undefined] should be checked."#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "Reference 'undefined' not found");
@@ -356,7 +358,7 @@ fn test_list_items_excluded() {
 + [X] Yet another one
 
 But this [reference][undefined] should still be checked."#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
 }
@@ -389,7 +391,7 @@ Here's an [undefined link][broken] and an ![undefined image][missing].
 [ref2]: http://example.com/ref2
 [ref3]: http://example.com/ref3
 [ref4]: http://example.com/ref4"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 2);
 
@@ -403,7 +405,7 @@ Here's an [undefined link][broken] and an ![undefined image][missing].
 fn test_empty_content() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -412,7 +414,7 @@ fn test_empty_content() {
 fn test_no_references() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "# Just a heading\n\nSome regular text\n\n> A blockquote";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -425,7 +427,7 @@ fn test_empty_reference_label() {
     let content = r#"This is a [link text][] reference.
 
 [link text]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -434,7 +436,7 @@ fn test_empty_reference_label() {
 fn test_empty_reference_label_undefined() {
     let rule = MD052ReferenceLinkImages::new();
     let content = "This is a [link text][] reference.";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(result.len(), 1);
     assert_eq!(result[0].message, "Reference 'link text' not found");
@@ -446,7 +448,7 @@ fn test_reference_with_special_chars() {
     let content = r#"Link with [special-chars_123][ref-with_special.chars].
 
 [ref-with_special.chars]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -470,7 +472,7 @@ fn test_reference_in_nested_structures() {
 [ref4]: http://example.com/4
 [ref5]: http://example.com/5
 [ref6]: http://example.com/6"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -483,7 +485,7 @@ fn test_reference_definitions_with_titles() {
 [ref1]: http://example.com "Title in double quotes"
 [ref2]: http://example.com 'Title in single quotes'
 [ref3]: http://example.com (Title in parentheses)"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -495,7 +497,7 @@ fn test_multiline_reference_links() {
 link text][ref] that spans lines.
 
 [ref]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -507,7 +509,7 @@ fn test_adjacent_reference_links() {
 
 [ref1]: http://example.com/1
 [ref2]: http://example.com/2"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -522,7 +524,7 @@ fn test_reference_definition_indentation() {
  [ref2]: http://example.com/2
   [ref3]: http://example.com/3
    [ref4]: http://example.com/4"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty());
 }
@@ -534,7 +536,7 @@ fn test_reference_definition_too_indented() {
     let content = r#"[link][ref]
 
     [ref]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Debug: check what's happening
     if result.is_empty() {
@@ -559,7 +561,7 @@ fn test_output_example_section_ignored() {
 [undefined2][missing] should be caught here.
 
 [ref]: http://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Debug: print what's being detected
     for (i, warning) in result.iter().enumerate() {
@@ -580,7 +582,7 @@ fn test_shortcut_reference_with_nested_brackets() {
     let content = r#"This is [`Union[T, None]`] text.
 
 [`union[t, none]`]: https://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -595,7 +597,7 @@ fn test_reference_definition_with_nested_brackets() {
     let content = r#"See [`dataclasses.InitVar`] for details.
 
 [`dataclasses.initvar`]: https://docs.python.org/3/library/dataclasses.html#dataclasses.InitVar"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -615,7 +617,7 @@ For arrays use [`List[int]`] or [`Array[str, 10]`].
 [`union[t, none]`]: https://example.com/union
 [`list[int]`]: https://example.com/list
 [`array[str, 10]`]: https://example.com/array"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(result.is_empty(), "Should handle all complex nested bracket cases");
 }
@@ -628,7 +630,7 @@ fn test_undefined_reference_with_nested_brackets() {
     let content = r#"This [`Dict[str, Any]`] is undefined.
 
 [`list[int]`]: https://example.com"#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     // Should not flag type annotations as undefined references
     assert_eq!(
@@ -655,7 +657,7 @@ fn test_issue_81_toml_code_block_not_parsed() {
     ```
 
 3. Add any required dependencies to the `Cargo.toml` file."#;
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -670,7 +672,7 @@ fn test_mkdocs_backtick_wrapped_auto_references() {
 
     // Module.Class pattern with backticks
     let content = "[`module.Class`][]";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -679,7 +681,7 @@ fn test_mkdocs_backtick_wrapped_auto_references() {
 
     // Reference with explicit ID
     let content = "[`module.Class`][ref]";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -688,7 +690,7 @@ fn test_mkdocs_backtick_wrapped_auto_references() {
 
     // Path-like reference with backticks
     let content = "[`api/endpoint`][]";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -697,7 +699,7 @@ fn test_mkdocs_backtick_wrapped_auto_references() {
 
     // Multiple backtick-wrapped references
     let content = "See [`module.func`][], [`package.Class`][], and [`api/endpoint`][] for details.";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -706,7 +708,7 @@ fn test_mkdocs_backtick_wrapped_auto_references() {
 
     // Should still flag in standard mode (no MkDocs auto-references)
     let content = "[`module.Class`][]";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(
         result.len(),
@@ -716,7 +718,7 @@ fn test_mkdocs_backtick_wrapped_auto_references() {
 
     // Should still flag truly undefined references even in MkDocs mode
     let content = "[undefined_reference][]";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs, None);
     let result = rule.check(&ctx).unwrap();
     assert_eq!(
         result.len(),
@@ -726,7 +728,7 @@ fn test_mkdocs_backtick_wrapped_auto_references() {
 
     // Backtick-wrapped images should also work
     let content = "![`module.Class`][]";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -735,7 +737,7 @@ fn test_mkdocs_backtick_wrapped_auto_references() {
 
     // Single-word backtick-wrapped identifiers should also work (the actual issue #97 example)
     let content = "[`str`][]";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -744,7 +746,7 @@ fn test_mkdocs_backtick_wrapped_auto_references() {
 
     // Multiple single-word backtick-wrapped identifiers
     let content = "See [`str`][], [`int`][], and [`bool`][] for details.";
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::MkDocs, None);
     let result = rule.check(&ctx).unwrap();
     assert!(
         result.is_empty(),
@@ -772,7 +774,7 @@ struct Ok;
 > ```
 "#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should not flag [derive(Debug)] inside code blocks, even if they're in block quotes
@@ -806,7 +808,7 @@ let x = vec![1, 2, 3];
 > ```
 "#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
     // Should not flag any of these as undefined references
@@ -819,7 +821,8 @@ let x = vec![1, 2, 3];
 
 #[test]
 fn test_actual_reference_in_quote_outside_code() {
-    // Make sure we still catch actual undefined references in blockquotes
+    // Make sure we don't flag code block content like #[derive(Debug)]
+    // Note: [reference] is a shortcut reference which is NOT checked by default
     let rule = MD052ReferenceLinkImages::new();
 
     let content = r#"> This is a [reference] in a blockquote
@@ -830,14 +833,14 @@ fn test_actual_reference_in_quote_outside_code() {
 > ```
 "#;
 
-    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard);
+    let ctx = LintContext::new(content, rumdl_lib::config::MarkdownFlavor::Standard, None);
     let result = rule.check(&ctx).unwrap();
 
-    // Should flag [reference] but not [derive(Debug)]
+    // With shortcut_syntax: false (default), [reference] is not checked
+    // Only ensure we don't flag code block content like [derive(Debug)]
     assert_eq!(
         result.len(),
-        1,
-        "Should flag [reference] but not code block content. Got: {result:?}"
+        0,
+        "Shortcut references are not checked by default, and code block content should be ignored. Got: {result:?}"
     );
-    assert!(result[0].message.contains("reference"));
 }
